@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2024 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
 #include "utils.h"
 
 class Settings;
-class Suppressions;
+struct Suppressions;
 class Library;
 
 /// @addtogroup CLI
@@ -53,9 +53,8 @@ public:
      * @param settings Settings instance that will be modified according to
      * options user has given.
      * @param suppressions Suppressions instance that keeps the suppressions
-     * @param suppressionsNoFail Suppressions instance that keeps the "do not fail" suppressions
      */
-    CmdLineParser(CmdLineLogger &logger, Settings &settings, Suppressions &suppressions, Suppressions &suppressionsNoFail);
+    CmdLineParser(CmdLineLogger &logger, Settings &settings, Suppressions &suppressions);
 
     enum class Result { Success, Exit, Fail };
 
@@ -103,6 +102,11 @@ public:
         return mIgnoredPaths;
     }
 
+    /**
+     * Get Cppcheck version
+     */
+    std::string getVersion() const;
+
 protected:
 
     /**
@@ -160,7 +164,6 @@ private:
     std::vector<std::string> mIgnoredPaths;
     Settings &mSettings;
     Suppressions &mSuppressions;
-    Suppressions &mSuppressionsNoFail;
     std::string mVSConfig;
 };
 
