@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2024 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,9 +28,9 @@
 #include <utility>
 #include <vector>
 
-class CppCheck;
 class Settings;
 class ErrorLogger;
+class SuppressionList;
 
 /**
  * This class works as an example of how CppCheck can be used in external
@@ -48,7 +48,7 @@ public:
      */
     CppCheckExecutor() = default;
     CppCheckExecutor(const CppCheckExecutor &) = delete;
-    void operator=(const CppCheckExecutor&) = delete;
+    CppCheckExecutor& operator=(const CppCheckExecutor&) = delete;
 
     /**
      * Starts the checking.
@@ -81,27 +81,27 @@ private:
 
 protected:
 
-    static bool reportSuppressions(const Settings &settings, bool unusedFunctionCheckEnabled, const std::list<std::pair<std::string, std::size_t>> &files, ErrorLogger& errorLogger);
+    static bool reportSuppressions(const Settings &settings, const SuppressionList& suppressions, bool unusedFunctionCheckEnabled, const std::list<std::pair<std::string, std::size_t>> &files, const std::list<FileSettings>& fileSettings, ErrorLogger& errorLogger);
 
     /**
      * Wrapper around check_internal
      *   - installs optional platform dependent signal handling
      *
-     * @param cppcheck cppcheck instance
+     * @param settings the settings
      **/
-    int check_wrapper(CppCheck& cppcheck);
+    int check_wrapper(const Settings& settings);
 
     /**
      * Starts the checking.
      *
-     * @param cppcheck cppcheck instance
+     * @param settings the settings
      * @return EXIT_FAILURE if arguments are invalid or no input files
      *         were found.
      *         If errors are found and --error-exitcode is used,
      *         given value is returned instead of default 0.
      *         If no errors are found, 0 is returned.
      */
-    int check_internal(CppCheck& cppcheck) const;
+    int check_internal(const Settings& settings) const;
 
     /**
      * Filename associated with size of file
@@ -116,9 +116,6 @@ protected:
      */
     static FILE* mExceptionOutput;
 #endif
-
-    class StdLogger;
-    StdLogger* mStdLogger{};
 };
 
 #endif // CPPCHECKEXECUTOR_H
