@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2024 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,8 +39,10 @@
 #include <iostream>
 #include <list>
 #include <map>
-#include <sstream> // IWYU pragma: keep
+#include <sstream>
 #include <sys/select.h>
+#include <sys/time.h>
+#include <sys/types.h>
 #include <sys/wait.h>
 #include <unistd.h>
 #include <utility>
@@ -61,7 +63,7 @@ enum class Color;
 using std::memset;
 
 
-ProcessExecutor::ProcessExecutor(const std::list<std::pair<std::string, std::size_t>> &files, const std::list<FileSettings>& fileSettings, const Settings &settings, Suppressions &suppressions, ErrorLogger &errorLogger, CppCheck::ExecuteCmdFn executeCommand)
+ProcessExecutor::ProcessExecutor(const std::list<std::pair<std::string, std::size_t>> &files, const std::list<FileSettings>& fileSettings, const Settings &settings, SuppressionList &suppressions, ErrorLogger &errorLogger, CppCheck::ExecuteCmdFn executeCommand)
     : Executor(files, fileSettings, settings, suppressions, errorLogger)
     , mExecuteCommand(std::move(executeCommand))
 {
@@ -107,11 +109,11 @@ namespace {
         void writeToPipe(PipeSignal type, const std::string &data) const
         {
             {
-                const char t = static_cast<char>(type);
+                const auto t = static_cast<char>(type);
                 writeToPipeInternal(type, &t, 1);
             }
 
-            const unsigned int len = static_cast<unsigned int>(data.length());
+            const auto len = static_cast<unsigned int>(data.length());
             {
                 static constexpr std::size_t l_size = sizeof(unsigned int);
                 writeToPipeInternal(type, &len, l_size);
@@ -392,7 +394,7 @@ void ProcessExecutor::reportInternalChildErr(const std::string &childname, const
 {
     std::list<ErrorMessage::FileLocation> locations;
     locations.emplace_back(childname, 0, 0);
-    const ErrorMessage errmsg(locations,
+    const ErrorMessage errmsg(std::move(locations),
                               emptyString,
                               Severity::error,
                               "Internal error: " + msg,
