@@ -133,7 +133,7 @@ private:
      * @brief Index of the default application.
      *
      */
-    int mDefaultApplicationIndex;
+    int mDefaultApplicationIndex = -1;
 };
 /// @}
 #endif // APPLICATIONLIST_H
