@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2024 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,6 +24,8 @@
 #include "suppressions.h"
 
 #include <atomic>
+#include <string>
+#include <vector>
 
 #include <QList>
 #include <QObject>
@@ -68,7 +70,7 @@ public:
         mClangIncludePaths = s;
     }
 
-    void setSuppressions(const QList<Suppressions::Suppression> &s) {
+    void setSuppressions(const QList<SuppressionList::Suppression> &s) {
         mSuppressions = s;
     }
 
@@ -92,6 +94,8 @@ public:
      */
     static QString clangTidyCmd();
 
+    static int executeCommand(std::string exe, std::vector<std::string> args, std::string redirect, std::string &output);
+
 signals:
 
     /**
@@ -134,13 +138,13 @@ private:
 
     void parseClangErrors(const QString &tool, const QString &file0, QString err);
 
-    bool isSuppressed(const Suppressions::ErrorMessage &errorMessage) const;
+    bool isSuppressed(const SuppressionList::ErrorMessage &errorMessage) const;
 
     QStringList mFiles;
     bool mAnalyseWholeProgram{};
     QStringList mAddonsAndTools;
     QStringList mClangIncludePaths;
-    QList<Suppressions::Suppression> mSuppressions;
+    QList<SuppressionList::Suppression> mSuppressions;
 };
 /// @}
 #endif // CHECKTHREAD_H
