@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2024 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #include "common.h"
 #include "config.h"
 #include "erroritem.h"
+#include "errorlogger.h"
 #include "errortypes.h"
 #include "path.h"
 #include "projectfile.h"
@@ -32,6 +33,8 @@
 #include "threadhandler.h"
 #include "xmlreportv2.h"
 
+#include <utility>
+
 #include <QAction>
 #include <QApplication>
 #include <QClipboard>
@@ -110,7 +113,7 @@ void ResultsTree::initialize(QSettings *settings, ApplicationList *list, ThreadH
 
 QStandardItem *ResultsTree::createNormalItem(const QString &name)
 {
-    QStandardItem *item = new QStandardItem(name);
+    auto *item = new QStandardItem(name);
     item->setData(name, Qt::ToolTipRole);
     item->setEditable(false);
     return item;
@@ -118,7 +121,7 @@ QStandardItem *ResultsTree::createNormalItem(const QString &name)
 
 QStandardItem *ResultsTree::createCheckboxItem(bool checked)
 {
-    QStandardItem *item = new QStandardItem;
+    auto *item = new QStandardItem;
     item->setCheckable(true);
     item->setCheckState(checked ? Qt::Checked : Qt::Unchecked);
     item->setEnabled(false);
@@ -127,7 +130,7 @@ QStandardItem *ResultsTree::createCheckboxItem(bool checked)
 
 QStandardItem *ResultsTree::createLineNumberItem(const QString &linenumber)
 {
-    QStandardItem *item = new QStandardItem();
+    auto *item = new QStandardItem();
     item->setData(QVariant(linenumber.toInt()), Qt::DisplayRole);
     item->setToolTip(linenumber);
     item->setTextAlignment(Qt::AlignRight | Qt::AlignVCenter);
@@ -421,7 +424,7 @@ void ResultsTree::loadSettings()
     mSaveAllErrors = mSettings->value(SETTINGS_SAVE_ALL_ERRORS, false).toBool();
     mShowFullPath = mSettings->value(SETTINGS_SHOW_FULL_PATH, false).toBool();
 
-    showIdColumn(mSettings->value(SETTINGS_SHOW_ERROR_ID, false).toBool());
+    showIdColumn(mSettings->value(SETTINGS_SHOW_ERROR_ID, true).toBool());
     showInconclusiveColumn(mSettings->value(SETTINGS_INCONCLUSIVE_ERRORS, false).toBool());
 }
 
@@ -611,7 +614,7 @@ void ResultsTree::contextMenuEvent(QContextMenuEvent * e)
 
         //Create a signal mapper so we don't have to store data to class
         //member variables
-        QSignalMapper *signalMapper = new QSignalMapper(this);
+        auto *signalMapper = new QSignalMapper(this);
 
         if (mContextItem && mApplications->getApplicationCount() > 0 && mContextItem->parent()) {
             //Create an action for the application
@@ -619,7 +622,7 @@ void ResultsTree::contextMenuEvent(QContextMenuEvent * e)
             if (defaultApplicationIndex < 0)
                 defaultApplicationIndex = 0;
             const Application& app = mApplications->getApplication(defaultApplicationIndex);
-            QAction *start = new QAction(app.getName(), &menu);
+            auto *start = new QAction(app.getName(), &menu);
             if (multipleSelection)
                 start->setDisabled(true);
 
@@ -646,11 +649,11 @@ void ResultsTree::contextMenuEvent(QContextMenuEvent * e)
             }
 
             //Create an action for the application
-            QAction *recheckAction          = new QAction(tr("Recheck"), &menu);
-            QAction *copyAction             = new QAction(tr("Copy"), &menu);
-            QAction *hide                   = new QAction(tr("Hide"), &menu);
-            QAction *hideallid              = new QAction(tr("Hide all with id"), &menu);
-            QAction *opencontainingfolder   = new QAction(tr("Open containing folder"), &menu);
+            auto *recheckAction          = new QAction(tr("Recheck"), &menu);
+            auto *copyAction             = new QAction(tr("Copy"), &menu);
+            auto *hide                   = new QAction(tr("Hide"), &menu);
+            auto *hideallid              = new QAction(tr("Hide all with id"), &menu);
+            auto *opencontainingfolder   = new QAction(tr("Open containing folder"), &menu);
 
             if (multipleSelection) {
                 hideallid->setDisabled(true);
@@ -668,7 +671,7 @@ void ResultsTree::contextMenuEvent(QContextMenuEvent * e)
             menu.addAction(hide);
             menu.addAction(hideallid);
 
-            QAction *suppress = new QAction(tr("Suppress selected id(s)"), &menu);
+            auto *suppress = new QAction(tr("Suppress selected id(s)"), &menu);
             {
                 QVariantMap data = mContextItem->data().toMap();
                 const QString messageId = data[ERRORID].toString();
@@ -691,7 +694,7 @@ void ResultsTree::contextMenuEvent(QContextMenuEvent * e)
                 menu.addSeparator();
                 QMenu *tagMenu = menu.addMenu(tr("Tag"));
                 {
-                    QAction *action = new QAction(tr("No tag"), tagMenu);
+                    auto *action = new QAction(tr("No tag"), tagMenu);
                     tagMenu->addAction(action);
                     connect(action, &QAction::triggered, [=]() {
                         tagSelectedItems(QString());
@@ -699,7 +702,7 @@ void ResultsTree::contextMenuEvent(QContextMenuEvent * e)
                 }
 
                 for (const QString& tagstr : currentProject->getTags()) {
-                    QAction *action = new QAction(tagstr, tagMenu);
+                    auto *action = new QAction(tagstr, tagMenu);
                     tagMenu->addAction(action);
                     connect(action, &QAction::triggered, [=]() {
                         tagSelectedItems(tagstr);
@@ -962,7 +965,7 @@ void ResultsTree::recheckSelectedFiles()
                 askFileDir(currentFile);
                 return;
             }
-            if (Path::isHeader(currentFile.toStdString())) {
+            if (Path::isHeader2(currentFile.toStdString())) {
                 if (!data[FILE0].toString().isEmpty() && !selectedItems.contains(data[FILE0].toString())) {
                     selectedItems<<((!mCheckPath.isEmpty() && (data[FILE0].toString().indexOf(mCheckPath) != 0)) ? (mCheckPath + "/" + data[FILE0].toString()) : data[FILE0].toString());
                     if (!selectedItems.contains(fileNameWithCheckPath))
@@ -972,7 +975,7 @@ void ResultsTree::recheckSelectedFiles()
                 selectedItems<<fileNameWithCheckPath;
         }
     }
-    emit checkSelected(selectedItems);
+    emit checkSelected(std::move(selectedItems));
 }
 
 void ResultsTree::hideAllIdResult()
@@ -1080,7 +1083,7 @@ void ResultsTree::suppressHash()
         QStandardItem *fileItem = item->parent();
         const QVariantMap data = item->data().toMap();
         if (projectFile && data.contains(HASH)) {
-            Suppressions::Suppression suppression;
+            SuppressionList::Suppression suppression;
             suppression.hash = data[HASH].toULongLong();
             suppression.errorId = data[ERRORID].toString().toStdString();
             suppression.fileName = data[FILENAME].toString().toStdString();
@@ -1231,7 +1234,7 @@ static int indexOf(const QList<ErrorItem> &list, const ErrorItem &item)
 void ResultsTree::updateFromOldReport(const QString &filename)
 {
     QList<ErrorItem> oldErrors;
-    XmlReportV2 oldReport(filename);
+    XmlReportV2 oldReport(filename, QString());
     if (oldReport.open()) {
         oldErrors = oldReport.read();
         oldReport.close();
@@ -1253,7 +1256,7 @@ void ResultsTree::updateFromOldReport(const QString &filename)
                 error->setData(data);
                 fileItem->child(j, COLUMN_SINCE_DATE)->setText(oldErrors[oldErrorIndex].sinceDate);
             } else if (oldErrorIndex < 0 || data[SINCEDATE].toString().isEmpty()) {
-                const QString sinceDate = QLocale::system().dateFormat(QLocale::ShortFormat);
+                const QString sinceDate = QLocale::system().toString(QDate::currentDate(), QLocale::ShortFormat);
                 data[SINCEDATE] = sinceDate;
                 error->setData(data);
                 fileItem->child(j, COLUMN_SINCE_DATE)->setText(sinceDate);
@@ -1334,7 +1337,7 @@ void ResultsTree::setCheckDirectory(const QString &dir)
 }
 
 
-QString ResultsTree::getCheckDirectory()
+const QString& ResultsTree::getCheckDirectory()
 {
     return mCheckPath;
 }
