@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2024 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -69,7 +69,7 @@ public:
      * @return List of available translations.
      *
      */
-    QList<TranslationInfo> getTranslations() const {
+    const QList<TranslationInfo>& getTranslations() const {
         return mTranslations;
     }
 
@@ -86,7 +86,7 @@ public:
      * @return ISO 639 language code for current translation.
      *
      */
-    QString getCurrentLanguage() const;
+    const QString& getCurrentLanguage() const;
 
     /**
      * @brief Get translation suggestion for the system.
