@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2024 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -50,7 +50,7 @@ static bool isBool(const Variable* var)
 //---------------------------------------------------------------------------
 void CheckBool::checkIncrementBoolean()
 {
-    if (!mSettings->severity.isEnabled(Severity::style))
+    if (!mSettings->severity.isEnabled(Severity::style) && !mSettings->isPremiumEnabled("incrementboolean"))
         return;
 
     logChecker("CheckBool::checkIncrementBoolean"); // style
@@ -113,6 +113,8 @@ void CheckBool::checkBitwiseOnBoolean()
                     continue;
                 const bool isBoolOp1 = astIsBool(tok->astOperand1());
                 const bool isBoolOp2 = astIsBool(tok->astOperand2());
+                if (!tok->astOperand1()->valueType() || !tok->astOperand2()->valueType())
+                    continue;
                 if (!(isBoolOp1 || isBoolOp2))
                     continue;
                 if (isCompound && (!isBoolOp1 || isBoolOp2))
@@ -120,7 +122,7 @@ void CheckBool::checkBitwiseOnBoolean()
                 if (tok->str() == "|" && !isConvertedToBool(tok) && !(isBoolOp1 && isBoolOp2))
                     continue;
                 // first operand will always be evaluated
-                if (!isConstExpression(tok->astOperand2(), mSettings->library, mTokenizer->isCPP()))
+                if (!isConstExpression(tok->astOperand2(), mSettings->library))
                     continue;
                 if (tok->astOperand2()->variable() && tok->astOperand2()->variable()->nameToken() == tok->astOperand2())
                     continue;
