@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2024 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -52,7 +52,7 @@ private:
         if (!tokenizer.isCPP())
             return;
 
-        CheckBoost checkBoost(&tokenizer, tokenizer.getSettings(), errorLogger);
+        CheckBoost checkBoost(&tokenizer, &tokenizer.getSettings(), errorLogger);
         checkBoost.checkBoostForeachModification();
     }
 
