@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2024 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -200,7 +200,7 @@ bool CheckCondition::assignIfParseScope(const Token * const assignTok,
                 // is variable changed in loop?
                 const Token *bodyStart = tok2->linkAt(1)->next();
                 const Token *bodyEnd   = bodyStart ? bodyStart->link() : nullptr;
-                if (!bodyEnd || bodyEnd->str() != "}" || isVariableChanged(bodyStart, bodyEnd, varid, !islocal, mSettings, mTokenizer->isCPP()))
+                if (!bodyEnd || bodyEnd->str() != "}" || isVariableChanged(bodyStart, bodyEnd, varid, !islocal, mSettings))
                     continue;
             }
 
@@ -417,8 +417,6 @@ void CheckCondition::comparison()
 
 void CheckCondition::comparisonError(const Token *tok, const std::string &bitop, MathLib::bigint value1, const std::string &op, MathLib::bigint value2, bool result)
 {
-    if (tok && (diag(tok) | diag(tok->astParent())))
-        return;
     std::ostringstream expression;
     expression << std::hex << "(X " << bitop << " 0x" << value1 << ") " << op << " 0x" << value2;
 
@@ -437,7 +435,7 @@ bool CheckCondition::isOverlappingCond(const Token * const cond1, const Token *
         return false;
 
     // same expressions
-    if (isSameExpression(mTokenizer->isCPP(), true, cond1, cond2, mSettings->library, pure, false))
+    if (isSameExpression(true, cond1, cond2, mSettings->library, pure, false))
         return true;
 
     // bitwise overlap for example 'x&7' and 'x==1'
@@ -460,7 +458,7 @@ bool CheckCondition::isOverlappingCond(const Token * const cond1, const Token *
         if (!num2->isNumber() || MathLib::isNegative(num2->str()))
             return false;
 
-        if (!isSameExpression(mTokenizer->isCPP(), true, expr1, expr2, mSettings->library, pure, false))
+        if (!isSameExpression(true, expr1, expr2, mSettings->library, pure, false))
             return false;
 
         const MathLib::bigint value1 = MathLib::toBigNumber(num1->str());
@@ -505,9 +503,9 @@ void CheckCondition::duplicateCondition()
             continue;
 
         ErrorPath errorPath;
-        if (!findExpressionChanged(cond1, scope.classDef->next(), cond2, mSettings, mTokenizer->isCPP()) &&
-            isSameExpression(mTokenizer->isCPP(), true, cond1, cond2, mSettings->library, true, true, &errorPath))
-            duplicateConditionError(cond1, cond2, errorPath);
+        if (!findExpressionChanged(cond1, scope.classDef->next(), cond2, mSettings) &&
+            isSameExpression(true, cond1, cond2, mSettings->library, true, true, &errorPath))
+            duplicateConditionError(cond1, cond2, std::move(errorPath));
     }
 }
 
@@ -555,12 +553,12 @@ void CheckCondition::multiCondition()
             if (tok2->astOperand2()) {
                 ErrorPath errorPath;
                 if (isOverlappingCond(cond1, tok2->astOperand2(), true) &&
-                    !findExpressionChanged(cond1, cond1, tok2->astOperand2(), mSettings, mTokenizer->isCPP()))
+                    !findExpressionChanged(cond1, cond1, tok2->astOperand2(), mSettings))
                     overlappingElseIfConditionError(tok2->astOperand2(), cond1->linenr());
                 else if (isOppositeCond(
-                             true, mTokenizer->isCPP(), cond1, tok2->astOperand2(), mSettings->library, true, true, &errorPath) &&
-                         !findExpressionChanged(cond1, cond1, tok2->astOperand2(), mSettings, mTokenizer->isCPP()))
-                    oppositeElseIfConditionError(cond1, tok2->astOperand2(), errorPath);
+                             true, cond1, tok2->astOperand2(), mSettings->library, true, true, &errorPath) &&
+                         !findExpressionChanged(cond1, cond1, tok2->astOperand2(), mSettings))
+                    oppositeElseIfConditionError(cond1, tok2->astOperand2(), std::move(errorPath));
             }
         }
     }
@@ -667,7 +665,7 @@ void CheckCondition::multiCondition2()
                 }
             } else if (!nonlocal && cond->isName()) {
                 // varid is 0. this is possibly a nonlocal variable..
-                nonlocal = Token::Match(cond->astParent(), "%cop%|(|[") || Token::Match(cond, "%name% .") || (mTokenizer->isCPP() && cond->str() == "this");
+                nonlocal = Token::Match(cond->astParent(), "%cop%|(|[") || Token::Match(cond, "%name% .") || (cond->isCpp() && cond->str() == "this");
             } else {
                 return ChildrenToVisit::op1_and_op2;
             }
@@ -705,13 +703,13 @@ void CheckCondition::multiCondition2()
             const Token * const endToken = tok->scope()->bodyEnd;
 
             for (; tok && tok != endToken; tok = tok->next()) {
-                if (isExpressionChangedAt(cond1, tok, 0, false, mSettings, mTokenizer->isCPP()))
+                if (isExpressionChangedAt(cond1, tok, 0, false, mSettings))
                     break;
                 if (Token::Match(tok, "if|return")) {
                     const Token * condStartToken = tok->str() == "if" ? tok->next() : tok;
                     const Token * condEndToken = tok->str() == "if" ? condStartToken->link() : Token::findsimplematch(condStartToken, ";");
                     // Does condition modify tracked variables?
-                    if (findExpressionChanged(cond1, condStartToken, condEndToken, mSettings, mTokenizer->isCPP()))
+                    if (findExpressionChanged(cond1, condStartToken, condEndToken, mSettings))
                         break;
 
                     // Condition..
@@ -725,14 +723,14 @@ void CheckCondition::multiCondition2()
                             if (!firstCondition)
                                 return ChildrenToVisit::none;
                             if (firstCondition->str() == "&&") {
-                                if (!isOppositeCond(false, mTokenizer->isCPP(), firstCondition, cond2, mSettings->library, true, true))
+                                if (!isOppositeCond(false, firstCondition, cond2, mSettings->library, true, true))
                                     return ChildrenToVisit::op1_and_op2;
                             }
                             if (!firstCondition->hasKnownIntValue()) {
-                                if (!isReturnVar && isOppositeCond(false, mTokenizer->isCPP(), firstCondition, cond2, mSettings->library, true, true, &errorPath)) {
+                                if (!isReturnVar && isOppositeCond(false, firstCondition, cond2, mSettings->library, true, true, &errorPath)) {
                                     if (!isAliased(vars))
                                         oppositeInnerConditionError(firstCondition, cond2, errorPath);
-                                } else if (!isReturnVar && isSameExpression(mTokenizer->isCPP(), true, firstCondition, cond2, mSettings->library, true, true, &errorPath)) {
+                                } else if (!isReturnVar && isSameExpression(true, firstCondition, cond2, mSettings->library, true, true, &errorPath)) {
                                     identicalInnerConditionError(firstCondition, cond2, errorPath);
                                 }
                             }
@@ -744,7 +742,7 @@ void CheckCondition::multiCondition2()
                                 return ChildrenToVisit::op1_and_op2;
 
                             if ((!cond1->hasKnownIntValue() || !secondCondition->hasKnownIntValue()) &&
-                                isSameExpression(mTokenizer->isCPP(), true, cond1, secondCondition, mSettings->library, true, true, &errorPath)) {
+                                isSameExpression(true, cond1, secondCondition, mSettings->library, true, true, &errorPath)) {
                                 if (!isAliased(vars) && !mTokenizer->hasIfdef(cond1, secondCondition)) {
                                     identicalConditionAfterEarlyExitError(cond1, secondCondition, errorPath);
                                     return ChildrenToVisit::done;
@@ -755,7 +753,7 @@ void CheckCondition::multiCondition2()
                     }
                 }
                 if (Token::Match(tok, "%name% (") &&
-                    isVariablesChanged(tok, tok->linkAt(1), 0, varsInCond, mSettings, mTokenizer->isCPP())) {
+                    isVariablesChanged(tok, tok->linkAt(1), 0, varsInCond, mSettings)) {
                     break;
                 }
                 if (Token::Match(tok, "%type% (") && nonlocal && isNonConstFunctionCall(tok, mSettings->library)) // non const function call -> bailout if there are nonlocal variables
@@ -784,7 +782,7 @@ void CheckCondition::multiCondition2()
                         break;
                     }
                     const bool changed = std::any_of(vars.cbegin(), vars.cend(), [&](int varid) {
-                        return isVariableChanged(tok1, tok2, varid, nonlocal, mSettings, mTokenizer->isCPP());
+                        return isVariableChanged(tok1, tok2, varid, nonlocal, mSettings);
                     });
                     if (changed)
                         break;
@@ -801,9 +799,9 @@ void CheckCondition::multiCondition2()
                         if (Token::Match(parent->astParent(), "%assign%|++|--"))
                             break;
                     }
-                    if (mTokenizer->isCPP() && Token::Match(tok, "%name% <<") && (!tok->valueType() || !tok->valueType()->isIntegral()))
+                    if (tok->isCpp() && Token::Match(tok, "%name% <<") && (!tok->valueType() || !tok->valueType()->isIntegral()))
                         break;
-                    if (isLikelyStreamRead(mTokenizer->isCPP(), tok->next()) || isLikelyStreamRead(mTokenizer->isCPP(), tok->previous()))
+                    if (isLikelyStreamRead(tok->next()) || isLikelyStreamRead(tok->previous()))
                         break;
                     if (Token::Match(tok, "%name% [")) {
                         const Token *tok2 = tok->linkAt(1);
@@ -1147,7 +1145,7 @@ void CheckCondition::checkIncorrectLogicOperator()
                 ((tok->str() == "||" && tok->astOperand2()->str() == "&&") ||
                  (tok->str() == "&&" && tok->astOperand2()->str() == "||"))) {
                 const Token* tok2 = tok->astOperand2()->astOperand1();
-                if (isOppositeCond(true, mTokenizer->isCPP(), tok->astOperand1(), tok2, mSettings->library, true, false)) {
+                if (isOppositeCond(true, tok->astOperand1(), tok2, mSettings->library, true, false)) {
                     std::string expr1(tok->astOperand1()->expressionString());
                     std::string expr2(tok->astOperand2()->astOperand1()->expressionString());
                     std::string expr3(tok->astOperand2()->astOperand2()->expressionString());
@@ -1179,7 +1177,7 @@ void CheckCondition::checkIncorrectLogicOperator()
                     redundantConditionError(tok, msg, false);
                     continue;
                 }
-                if (isSameExpression(mTokenizer->isCPP(), false, tok->astOperand1(), tok2, mSettings->library, true, true)) {
+                if (isSameExpression(false, tok->astOperand1(), tok2, mSettings->library, true, true)) {
                     std::string expr1(tok->astOperand1()->expressionString());
                     std::string expr2(tok->astOperand2()->astOperand1()->expressionString());
                     std::string expr3(tok->astOperand2()->astOperand2()->expressionString());
@@ -1195,7 +1193,7 @@ void CheckCondition::checkIncorrectLogicOperator()
                     }
 
                     const std::string cond1 = expr1 + " " + tok->str() + " (" + expr2 + " " + tok->astOperand2()->str() + " " + expr3 + ")";
-                    const std::string cond2 = expr1;
+                    const std::string cond2 = std::move(expr1);
 
                     const std::string cond1VerboseMsg = expr1VerboseMsg + " " + tok->str() + " " + expr2VerboseMsg + " " + tok->astOperand2()->str() + " " + expr3VerboseMsg;
                     const std::string& cond2VerboseMsg = expr1VerboseMsg;
@@ -1244,7 +1242,7 @@ void CheckCondition::checkIncorrectLogicOperator()
 
             // Opposite comparisons around || or && => always true or always false
             const bool isLogicalOr(tok->str() == "||");
-            if (!isfloat && isOppositeCond(isLogicalOr, mTokenizer->isCPP(), tok->astOperand1(), tok->astOperand2(), mSettings->library, true, true, &errorPath)) {
+            if (!isfloat && isOppositeCond(isLogicalOr, tok->astOperand1(), tok->astOperand2(), mSettings->library, true, true, &errorPath)) {
                 if (!isIfConstexpr(tok)) {
                     const bool alwaysTrue(isLogicalOr);
                     incorrectLogicOperatorError(tok, conditionString(tok), alwaysTrue, inconclusive, errorPath);
@@ -1255,9 +1253,9 @@ void CheckCondition::checkIncorrectLogicOperator()
             if (!parseable)
                 continue;
 
-            if (isSameExpression(mTokenizer->isCPP(), true, comp1, comp2, mSettings->library, true, true))
+            if (isSameExpression(true, comp1, comp2, mSettings->library, true, true))
                 continue; // same expressions => only report that there are same expressions
-            if (!isSameExpression(mTokenizer->isCPP(), true, expr1, expr2, mSettings->library, true, true))
+            if (!isSameExpression(true, expr1, expr2, mSettings->library, true, true))
                 continue;
 
 
@@ -1287,15 +1285,15 @@ void CheckCondition::checkIncorrectLogicOperator()
                 // 5 => testvalue is larger than both value1 and value2
                 bool result1, result2;
                 if (isfloat) {
-                    const double testvalue = getvalue<double>(test, d1, d2);
+                    const auto testvalue = getvalue<double>(test, d1, d2);
                     result1 = checkFloatRelation(op1, testvalue, d1);
                     result2 = checkFloatRelation(op2, testvalue, d2);
                 } else if (useUnsignedInt) {
-                    const MathLib::biguint testvalue = getvalue<MathLib::biguint>(test, u1, u2);
+                    const auto testvalue = getvalue<MathLib::biguint>(test, u1, u2);
                     result1 = checkIntRelation(op1, testvalue, u1);
                     result2 = checkIntRelation(op2, testvalue, u2);
                 } else {
-                    const MathLib::bigint testvalue = getvalue<MathLib::bigint>(test, i1, i2);
+                    const auto testvalue = getvalue<MathLib::bigint>(test, i1, i2);
                     result1 = checkIntRelation(op1, testvalue, i1);
                     result2 = checkIntRelation(op2, testvalue, i2);
                 }
@@ -1318,9 +1316,10 @@ void CheckCondition::checkIncorrectLogicOperator()
             const std::string cond2str = conditionString(not2, expr2, op2, value2);
             if (printWarning && (alwaysTrue || alwaysFalse)) {
                 const std::string text = cond1str + " " + tok->str() + " " + cond2str;
-                incorrectLogicOperatorError(tok, text, alwaysTrue, inconclusive, errorPath);
+                incorrectLogicOperatorError(tok, text, alwaysTrue, inconclusive, std::move(errorPath));
             } else if (printStyle && (firstTrue || secondTrue)) {
-                const int which = isfloat ? sufficientCondition(op1, not1, d1, op2, not2, d2, isAnd) : sufficientCondition(op1, not1, i1, op2, not2, i2, isAnd);
+                // cppcheck-suppress accessMoved - TODO: FP - see #12174
+                const int which = isfloat ? sufficientCondition(std::move(op1), not1, d1, std::move(op2), not2, d2, isAnd) : sufficientCondition(std::move(op1), not1, i1, std::move(op2), not2, i2, isAnd);
                 std::string text;
                 if (which != 0) {
                     text = "The condition '" + (which == 1 ? cond2str : cond1str) + "' is redundant since '" + (which == 1 ? cond1str : cond2str) + "' is sufficient.";
@@ -1420,8 +1419,6 @@ void CheckCondition::clarifyCondition()
     if (!mSettings->severity.isEnabled(Severity::style) && !mSettings->isPremiumEnabled("clarifyCondition"))
         return;
 
-    const bool isC = mTokenizer->isC();
-
     logChecker("CheckCondition::clarifyCondition"); // style
 
     const SymbolDatabase *symbolDatabase = mTokenizer->getSymbolDatabase();
@@ -1433,7 +1430,7 @@ void CheckCondition::clarifyCondition()
                         tok2 = tok2->link();
                     else if (tok2->isComparisonOp()) {
                         // This might be a template
-                        if (!isC && tok2->link())
+                        if (!tok2->isC() && tok2->link())
                             break;
                         if (Token::simpleMatch(tok2->astParent(), "?"))
                             break;
@@ -1543,16 +1540,23 @@ void CheckCondition::alwaysTrueFalse()
                 continue;
             if (Token::Match(tok, "! %num%|%bool%|%char%"))
                 continue;
-            if (Token::Match(tok, "%oror%|&&") &&
-                (tok->astOperand1()->hasKnownIntValue() || tok->astOperand2()->hasKnownIntValue()))
-                continue;
+            if (Token::Match(tok, "%oror%|&&")) {
+                bool bail = false;
+                for (const Token* op : { tok->astOperand1(), tok->astOperand2() }) {
+                    if (op->hasKnownIntValue() && (!op->isLiteral() || op->isBoolean())) {
+                        bail = true;
+                        break;
+                    }
+                }
+                if (bail)
+                    continue;
+            }
             if (Token::simpleMatch(tok, ":"))
                 continue;
             if (Token::Match(tok->astOperand1(), "%name% (") && Token::simpleMatch(tok->astParent(), "return"))
                 continue;
-            if (tok->isComparisonOp() && isWithoutSideEffects(mTokenizer->isCPP(), tok->astOperand1()) &&
-                isSameExpression(mTokenizer->isCPP(),
-                                 true,
+            if (tok->isComparisonOp() && isWithoutSideEffects(tok->astOperand1()) &&
+                isSameExpression(true,
                                  tok->astOperand1(),
                                  tok->astOperand2(),
                                  mSettings->library,
@@ -1569,8 +1573,8 @@ void CheckCondition::alwaysTrueFalse()
             {
                 const ValueFlow::Value *zeroValue = nullptr;
                 const Token *nonZeroExpr = nullptr;
-                if (CheckOther::comparisonNonZeroExpressionLessThanZero(tok, &zeroValue, &nonZeroExpr) ||
-                    CheckOther::testIfNonZeroExpressionIsPositive(tok, &zeroValue, &nonZeroExpr))
+                if (CheckOther::comparisonNonZeroExpressionLessThanZero(tok, zeroValue, nonZeroExpr, /*suppress*/ true) ||
+                    CheckOther::testIfNonZeroExpressionIsPositive(tok, zeroValue, nonZeroExpr))
                     continue;
             }
 
@@ -1680,8 +1684,7 @@ void CheckCondition::checkInvalidTestForOverflow()
                 if (expr->hasKnownIntValue())
                     continue;
 
-                if (!isSameExpression(mTokenizer->isCPP(),
-                                      true,
+                if (!isSameExpression(true,
                                       expr,
                                       lhs->astSibling(),
                                       mSettings->library,
@@ -1831,10 +1834,10 @@ void CheckCondition::checkDuplicateConditionalAssign()
                 isRedundant = (isNegation && val == 0) || (!isNegation && val == 1);
             } else { // comparison
                 if (!isSameExpression(
-                        mTokenizer->isCPP(), true, condTok->astOperand1(), assignTok->astOperand1(), mSettings->library, true, true))
+                        true, condTok->astOperand1(), assignTok->astOperand1(), mSettings->library, true, true))
                     continue;
                 if (!isSameExpression(
-                        mTokenizer->isCPP(), true, condTok->astOperand2(), assignTok->astOperand2(), mSettings->library, true, true))
+                        true, condTok->astOperand2(), assignTok->astOperand2(), mSettings->library, true, true))
                     continue;
             }
             duplicateConditionalAssignError(condTok, assignTok, isRedundant);
