@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2024 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,7 +31,6 @@
 
 #include <map>
 #include <string>
-#include <utility>
 
 class Token;
 class ErrorLogger;
@@ -60,7 +59,7 @@ private:
 
     /** @brief Run checks against the normal token list */
     void runChecks(const Tokenizer &tokenizer, ErrorLogger *errorLogger) override {
-        CheckFunctions checkFunctions(&tokenizer, tokenizer.getSettings(), errorLogger);
+        CheckFunctions checkFunctions(&tokenizer, &tokenizer.getSettings(), errorLogger);
 
         checkFunctions.checkIgnoredReturnValue();
         checkFunctions.checkMissingReturn();  // Missing "return" in exit path
