@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2024 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,16 +23,16 @@
 #include "standards.h"
 #include "suppressions.h"
 #include "token.h"
-#include "tokenize.h"
+#include "tokenlist.h"
 #include "utils.h"
 
 #include <algorithm>
 #include <cstdlib>
 #include <cstring>
-#include <fstream> // IWYU pragma: keep
+#include <fstream>
 #include <iostream>
 #include <iterator>
-#include <sstream> // IWYU pragma: keep
+#include <sstream>
 #include <unordered_set>
 #include <utility>
 
@@ -137,7 +137,7 @@ static bool simplifyPathWithVariables(std::string &s, std::map<std::string, std:
     }
     if (s.find("$(") != std::string::npos)
         return false;
-    s = Path::simplifyPath(Path::fromNativeSeparators(s));
+    s = Path::simplifyPath(Path::fromNativeSeparators(std::move(s)));
     return true;
 }
 
@@ -337,7 +337,7 @@ void ImportProject::fsParseCommand(FileSettings& fs, const std::string& command)
             // we can only set it globally but in this context it needs to be treated per file
         }
     }
-    fsSetDefines(fs, defs);
+    fsSetDefines(fs, std::move(defs));
 }
 
 bool ImportProject::importCompileCommands(std::istream &istr)
@@ -358,7 +358,7 @@ bool ImportProject::importCompileCommands(std::istream &istr)
         if (!endsWith(dirpath, '/'))
             dirpath += '/';
 
-        const std::string directory = dirpath;
+        const std::string directory = std::move(dirpath);
 
         std::string command;
         if (obj.count("arguments")) {
@@ -455,9 +455,11 @@ bool ImportProject::importSln(std::istream &istr, const std::string &path, const
         if (pos1 == std::string::npos)
             continue;
         std::string vcxproj(line.substr(pos1+1, pos-pos1+7));
+        vcxproj = Path::toNativeSeparators(std::move(vcxproj));
         if (!Path::isAbsolute(vcxproj))
             vcxproj = path + vcxproj;
-        if (!importVcxproj(Path::fromNativeSeparators(vcxproj), variables, emptyString, fileFilters)) {
+        vcxproj = Path::fromNativeSeparators(std::move(vcxproj));
+        if (!importVcxproj(vcxproj, variables, emptyString, fileFilters)) {
             printError("failed to load '" + vcxproj + "' from Visual Studio solution");
             return false;
         }
@@ -551,6 +553,8 @@ namespace {
             }
         }
 
+        // see https://learn.microsoft.com/en-us/visualstudio/msbuild/msbuild-conditions
+        // properties are .NET String objects and you can call any of its members on them
         bool conditionIsTrue(const ProjectConfiguration &p) const {
             if (condition.empty())
                 return true;
@@ -558,13 +562,14 @@ namespace {
             replaceAll(c, "$(Configuration)", p.configuration);
             replaceAll(c, "$(Platform)", p.platformStr);
 
-            // TODO : Better evaluation
-            Settings s;
+            // TODO: improve evaluation
+            const Settings s;
+            TokenList tokenlist(&s);
             std::istringstream istr(c);
-            Tokenizer tokenizer(&s);
-            tokenizer.tokenize(istr,"vcxproj");
-            for (const Token *tok = tokenizer.tokens(); tok; tok = tok->next()) {
+            tokenlist.createTokens(istr, Standards::Language::C); // TODO: check result
+            for (const Token *tok = tokenlist.front(); tok; tok = tok->next()) {
                 if (tok->str() == "(" && tok->astOperand1() && tok->astOperand2()) {
+                    // TODO: this is wrong - it is Contains() not Equals()
                     if (tok->astOperand1()->expressionString() == "Configuration.Contains")
                         return ('\'' + p.configuration + '\'') == tok->astOperand2()->str();
                 }
@@ -628,7 +633,7 @@ static void importPropertyGroup(const tinyxml2::XMLElement *node, std::map<std::
             const std::string::size_type pos = path.find("$(IncludePath)");
             if (pos != std::string::npos)
                 path.replace(pos, 14U, includePath);
-            includePath = path;
+            includePath = std::move(path);
         }
     }
 }
@@ -757,6 +762,7 @@ bool ImportProject::importVcxproj(const std::string &filename, std::map<std::str
             FileSettings fs;
             fs.filename = cfilename;
             fs.cfg = p.name;
+            // TODO: detect actual MSC version
             fs.msc = true;
             fs.useMfc = useOfMfc;
             fs.defines = "_WIN32=1";
@@ -1116,9 +1122,12 @@ bool ImportProject::importCppcheckGuiProject(std::istream &istr, Settings *setti
     const std::string &path = mPath;
 
     std::list<std::string> paths;
-    std::list<Suppressions::Suppression> suppressions;
+    std::list<SuppressionList::Suppression> suppressions;
     Settings temp;
 
+    // default to --check-level=normal for import for now
+    temp.setCheckLevel(Settings::CheckLevel::normal);
+
     guiProject.analyzeAllVsConfigs.clear();
 
     bool checkLevelExhaustive = false;
@@ -1160,12 +1169,12 @@ bool ImportProject::importCppcheckGuiProject(std::istream &istr, Settings *setti
             for (const tinyxml2::XMLElement *child = node->FirstChildElement(); child; child = child->NextSiblingElement()) {
                 if (strcmp(child->Name(), CppcheckXml::SuppressionElementName) != 0)
                     continue;
-                Suppressions::Suppression s;
+                SuppressionList::Suppression s;
                 s.errorId = readSafe(child->GetText(), "");
                 s.fileName = readSafe(child->Attribute("fileName"), "");
                 if (!s.fileName.empty())
                     s.fileName = joinRelativePath(path, s.fileName);
-                s.lineNumber = child->IntAttribute("lineNumber", Suppressions::Suppression::NO_LINE);
+                s.lineNumber = child->IntAttribute("lineNumber", SuppressionList::Suppression::NO_LINE);
                 s.symbolName = readSafe(child->Attribute("symbolName"), "");
                 s.hash = strToInt<std::size_t>(readSafe(child->Attribute("hash"), "0"));
                 suppressions.push_back(std::move(s));
@@ -1254,7 +1263,7 @@ bool ImportProject::importCppcheckGuiProject(std::istream &istr, Settings *setti
 
     for (const std::string &p : paths)
         guiProject.pathNames.push_back(p);
-    settings->nomsg.addSuppressions(std::move(suppressions));
+    settings->supprs.nomsg.addSuppressions(std::move(suppressions));
     settings->checkHeaders = temp.checkHeaders;
     settings->checkUnusedTemplates = temp.checkUnusedTemplates;
     settings->maxCtuDepth = temp.maxCtuDepth;
@@ -1262,9 +1271,9 @@ bool ImportProject::importCppcheckGuiProject(std::istream &istr, Settings *setti
     settings->safeChecks = temp.safeChecks;
 
     if (checkLevelExhaustive)
-        settings->setCheckLevelExhaustive();
+        settings->setCheckLevel(Settings::CheckLevel::exhaustive);
     else
-        settings->setCheckLevelNormal();
+        settings->setCheckLevel(Settings::CheckLevel::normal);
 
     return true;
 }
