@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2024 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,11 +26,13 @@
 #include <algorithm>
 #include <cstdlib>
 #include <sys/stat.h>
+#include <unordered_set>
 #include <utility>
 
 #include <simplecpp.h>
 
 #ifndef _WIN32
+#include <sys/types.h>
 #include <unistd.h>
 #else
 #include <direct.h>
@@ -193,6 +195,18 @@ std::string Path::getRelativePath(const std::string& absolutePath, const std::ve
     return absolutePath;
 }
 
+static const std::unordered_set<std::string> cpp_src_exts = {
+    ".cpp", ".cxx", ".cc", ".c++", ".tpp", ".txx", ".ipp", ".ixx"
+};
+
+static const std::unordered_set<std::string> c_src_exts = {
+    ".c", ".cl"
+};
+
+static const std::unordered_set<std::string> header_exts = {
+    ".h", ".hpp", ".h++", ".hxx", ".hh"
+};
+
 bool Path::isC(const std::string &path)
 {
     // In unix, ".C" is considered C++ file
@@ -220,15 +234,53 @@ bool Path::isCPP(const std::string &path)
 
 bool Path::acceptFile(const std::string &path, const std::set<std::string> &extra)
 {
-    return !Path::isHeader(path) && (Path::isCPP(path) || Path::isC(path) || extra.find(getFilenameExtension(path)) != extra.end());
+    bool header = false;
+    return (identify(path, &header) != Standards::Language::None && !header) || extra.find(getFilenameExtension(path)) != extra.end();
 }
 
+// cppcheck-suppress unusedFunction
 bool Path::isHeader(const std::string &path)
 {
     const std::string extension = getFilenameExtensionInLowerCase(path);
     return startsWith(extension, ".h");
 }
 
+Standards::Language Path::identify(const std::string &path, bool *header)
+{
+    // cppcheck-suppress uninitvar - TODO: FP
+    if (header)
+        *header = false;
+
+    std::string ext = getFilenameExtension(path);
+    if (ext == ".C")
+        return Standards::Language::CPP;
+    if (c_src_exts.find(ext) != c_src_exts.end())
+        return Standards::Language::C;
+    // cppcheck-suppress knownConditionTrueFalse - TODO: FP
+    if (!caseInsensitiveFilesystem())
+        strTolower(ext);
+    if (ext == ".h") {
+        if (header)
+            *header = true;
+        return Standards::Language::C; // treat as C for now
+    }
+    if (cpp_src_exts.find(ext) != cpp_src_exts.end())
+        return Standards::Language::CPP;
+    if (header_exts.find(ext) != header_exts.end()) {
+        if (header)
+            *header = true;
+        return Standards::Language::CPP;
+    }
+    return Standards::Language::None;
+}
+
+bool Path::isHeader2(const std::string &path)
+{
+    bool header;
+    (void)Path::identify(path, &header);
+    return header;
+}
+
 std::string Path::getAbsoluteFilePath(const std::string& filePath)
 {
     std::string absolute_path;
