@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2024 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,16 +16,26 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "config.h"
 #include "settings.h"
 #include "path.h"
 #include "summaries.h"
 #include "vfvalue.h"
 
+#include <cctype>
 #include <fstream>
 #include <sstream>
+#include <utility>
 
 #include "json.h"
 
+#ifndef _WIN32
+#include <unistd.h> // for getpid()
+#else
+#include <process.h> // for getpid()
+#endif
+
+
 std::atomic<bool> Settings::mTerminated;
 
 const char Settings::SafeChecks::XmlRootName[] = "safe-checks";
@@ -34,15 +44,27 @@ const char Settings::SafeChecks::XmlExternalFunctions[] = "external-functions";
 const char Settings::SafeChecks::XmlInternalFunctions[] = "internal-functions";
 const char Settings::SafeChecks::XmlExternalVariables[] = "external-variables";
 
+static int getPid()
+{
+#ifndef _WIN32
+    return getpid();
+#else
+    return _getpid();
+#endif
+}
+
 Settings::Settings()
 {
     severity.setEnabled(Severity::error, true);
     certainty.setEnabled(Certainty::normal, true);
-    setCheckLevelNormal();
+    setCheckLevel(Settings::CheckLevel::exhaustive);
+    executor = defaultExecutor();
+    pid = getPid();
 }
 
-std::string Settings::loadCppcheckCfg()
+std::string Settings::loadCppcheckCfg(Settings& settings, Suppressions& suppressions)
 {
+    // TODO: this always needs to be run *after* the Settings has been filled
     static const std::string cfgFilename = "cppcheck.cfg";
     std::string fileName;
 #ifdef FILESDIR
@@ -51,7 +73,8 @@ std::string Settings::loadCppcheckCfg()
 #endif
     // cppcheck-suppress knownConditionTrueFalse
     if (fileName.empty()) {
-        fileName = Path::getPathFromFilename(exename) + cfgFilename;
+        // TODO: make sure that exename is set
+        fileName = Path::getPathFromFilename(settings.exename) + cfgFilename;
         if (!Path::isFile(fileName))
             return "";
     }
@@ -73,7 +96,7 @@ std::string Settings::loadCppcheckCfg()
             const auto& v = it->second;
             if (!v.is<std::string>())
                 return "'productName' is not a string";
-            cppcheckCfgProductName = v.get<std::string>();
+            settings.cppcheckCfgProductName = v.get<std::string>();
         }
     }
     {
@@ -82,7 +105,7 @@ std::string Settings::loadCppcheckCfg()
             const auto& v = it->second;
             if (!v.is<std::string>())
                 return "'about' is not a string";
-            cppcheckCfgAbout = v.get<std::string>();
+            settings.cppcheckCfgAbout = v.get<std::string>();
         }
     }
     {
@@ -97,9 +120,9 @@ std::string Settings::loadCppcheckCfg()
                     return "'addons' array entry is not a string";
                 const std::string &s = v.get<std::string>();
                 if (!Path::isAbsolute(s))
-                    addons.emplace(Path::join(Path::getPathFromFilename(fileName), s));
+                    settings.addons.emplace(Path::join(Path::getPathFromFilename(fileName), s));
                 else
-                    addons.emplace(s);
+                    settings.addons.emplace(s);
             }
         }
     }
@@ -114,7 +137,7 @@ std::string Settings::loadCppcheckCfg()
                 if (!v.is<std::string>())
                     return "'suppressions' array entry is not a string";
                 const std::string &s = v.get<std::string>();
-                const std::string err = nomsg.addSuppressionLine(s);
+                const std::string err = suppressions.nomsg.addSuppressionLine(s);
                 if (!err.empty())
                     return "could not parse suppression '" + s + "' - " + err;
             }
@@ -126,13 +149,35 @@ std::string Settings::loadCppcheckCfg()
             const auto& v = it->second;
             if (!v.is<bool>())
                 return "'safety' is not a bool";
-            safety = safety || v.get<bool>();
+            settings.safety = settings.safety || v.get<bool>();
         }
     }
 
     return "";
 }
 
+std::pair<std::string, std::string> Settings::getNameAndVersion(const std::string& productName) {
+    if (productName.empty())
+        return {};
+    const std::string::size_type pos1 = productName.rfind(' ');
+    if (pos1 == std::string::npos)
+        return {};
+    if (pos1 + 2 >= productName.length())
+        return {};
+    for (auto pos2 = pos1 + 1; pos2 < productName.length(); ++pos2) {
+        const char c = productName[pos2];
+        const char prev = productName[pos2-1];
+        if (std::isdigit(c))
+            continue;
+        if (c == '.' && std::isdigit(prev))
+            continue;
+        if (c == 's' && pos2 + 1 == productName.length() && std::isdigit(prev))
+            continue;
+        return {};
+    }
+    return {productName.substr(0, pos1), productName.substr(pos1+1)};
+}
+
 std::string Settings::parseEnabled(const std::string &str, std::tuple<SimpleEnableGroup<Severity>, SimpleEnableGroup<Checks>> &groups)
 {
     // Enable parameters may be comma separated...
@@ -240,19 +285,20 @@ void Settings::loadSummaries()
     Summaries::loadReturn(buildDir, summaryReturn);
 }
 
-
-void Settings::setCheckLevelExhaustive()
+void Settings::setCheckLevel(CheckLevel level)
 {
-    // Checking can take a little while. ~ 10 times slower than normal analysis is OK.
-    performanceValueFlowMaxIfCount = -1;
-    performanceValueFlowMaxSubFunctionArgs = 256;
-}
-
-void Settings::setCheckLevelNormal()
-{
-    // Checking should finish in reasonable time.
-    performanceValueFlowMaxSubFunctionArgs = 8;
-    performanceValueFlowMaxIfCount = 100;
+    if (level == CheckLevel::normal) {
+        // Checking should finish in reasonable time.
+        checkLevel = level;
+        performanceValueFlowMaxSubFunctionArgs = 8;
+        performanceValueFlowMaxIfCount = 100;
+    }
+    else if (level == CheckLevel::exhaustive) {
+        // Checking can take a little while. ~ 10 times slower than normal analysis is OK.
+        checkLevel = CheckLevel::exhaustive;
+        performanceValueFlowMaxIfCount = -1;
+        performanceValueFlowMaxSubFunctionArgs = 256;
+    }
 }
 
 // TODO: auto generate these tables
@@ -536,7 +582,7 @@ void Settings::setMisraRuleTexts(const ExecuteCmdFn& executeCommand)
             else
                 arg = "--misra-c-2012-rule-texts";
             std::string output;
-            executeCommand(it->executable, {arg}, "2>&1", output);
+            executeCommand(it->executable, {std::move(arg)}, "2>&1", output);
             setMisraRuleTexts(output);
         }
     }
@@ -555,7 +601,7 @@ void Settings::setMisraRuleTexts(const std::string& data)
         std::string text = line.substr(pos + 1);
         if (id.empty() || text.empty())
             continue;
-        mMisraRuleTexts[id] = text;
+        mMisraRuleTexts[id] = std::move(text);
     }
 }
 
@@ -565,3 +611,14 @@ std::string Settings::getMisraRuleText(const std::string& id, const std::string&
     const auto it = mMisraRuleTexts.find(id.substr(id.rfind('-') + 1));
     return it != mMisraRuleTexts.end() ? it->second : text;
 }
+
+Settings::ExecutorType Settings::defaultExecutor()
+{
+    static constexpr ExecutorType defaultExecutor =
+#if defined(HAS_THREADING_MODEL_FORK)
+        ExecutorType::Process;
+#elif defined(HAS_THREADING_MODEL_THREAD)
+        ExecutorType::Thread;
+#endif
+    return defaultExecutor;
+}
