@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2024 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,7 +33,9 @@
 #include <atomic>
 #include <cstddef>
 #include <cstdint>
+#include <functional>
 #include <list>
+#include <map>
 #include <set>
 #include <string>
 #include <tuple>
@@ -99,7 +101,9 @@ private:
 public:
     Settings();
 
-    std::string loadCppcheckCfg();
+    static std::string loadCppcheckCfg(Settings& settings, Suppressions& suppressions);
+
+    static std::pair<std::string, std::string> getNameAndVersion(const std::string& productName);
 
     /** @brief addons, either filename of python/json file or json data */
     std::unordered_set<std::string> addons;
@@ -182,18 +186,26 @@ public:
     bool dump{};
     std::string dumpFile;
 
-    enum Language {
-        None, C, CPP
-    };
-
     /** @brief Name of the language that is enforced. Empty per default. */
-    Language enforcedLang{};
+    Standards::Language enforcedLang{};
 
 #if defined(USE_WINDOWS_SEH) || defined(USE_UNIX_SIGNAL_HANDLING)
     /** @brief Is --exception-handling given */
     bool exceptionHandling{};
 #endif
 
+    enum class ExecutorType
+    {
+#ifdef HAS_THREADING_MODEL_THREAD
+        Thread,
+#endif
+#ifdef HAS_THREADING_MODEL_FORK
+        Process
+#endif
+    };
+
+    ExecutorType executor;
+
     // argv[0]
     std::string exename;
 
@@ -237,12 +249,6 @@ public:
     /** @brief max template recursion */
     int maxTemplateRecursion = 100;
 
-    /** @brief suppress exitcode */
-    Suppressions nofail;
-
-    /** @brief suppress message (--suppressions) */
-    Suppressions nomsg;
-
     /** @brief write results (--output-file=&lt;file&gt;) */
     std::string outputFile;
 
@@ -252,10 +258,13 @@ public:
     int performanceValueFlowMaxTime = -1;
 
     /** @brief --performance-valueflow-max-if-count=C */
-    int performanceValueFlowMaxIfCount;
+    int performanceValueFlowMaxIfCount = -1;
 
     /** @brief max number of sets of arguments to pass to subfuncions in valueflow */
-    int performanceValueFlowMaxSubFunctionArgs;
+    int performanceValueFlowMaxSubFunctionArgs = 256;
+
+    /** @brief pid of cppcheck. Intention is that this is set in the main process. */
+    int pid;
 
     /** @brief plist output (--plist-output=&lt;dir&gt;) */
     std::string plistOutput;
@@ -263,6 +272,7 @@ public:
     /** @brief Extra arguments for Cppcheck Premium addon */
     std::string premiumArgs;
 
+    /** Is checker id enabled by premiumArgs */
     bool isPremiumEnabled(const char id[]) const;
 
     /** @brief Using -E for debugging purposes */
@@ -355,6 +365,9 @@ public:
     /** Struct contains standards settings */
     Standards standards;
 
+    /** @brief suppressions */
+    Suppressions supprs;
+
     /** @brief The output format in which the errors are printed in text mode,
         e.g. "{severity} {file}:{line} {message} {id}" */
     std::string templateFormat;
@@ -445,12 +458,25 @@ public:
         return jobs == 1;
     }
 
-    void setCheckLevelExhaustive();
-    void setCheckLevelNormal();
+    enum class CheckLevel {
+        normal,
+        exhaustive
+    };
+    CheckLevel checkLevel = CheckLevel::exhaustive;
+
+    void setCheckLevel(CheckLevel level);
+
+    using ExecuteCmdFn = std::function<int (std::string,std::vector<std::string>,std::string,std::string&)>;
+    void setMisraRuleTexts(const ExecuteCmdFn& executeCommand);
+    void setMisraRuleTexts(const std::string& data);
+    std::string getMisraRuleText(const std::string& id, const std::string& text) const;
+
+    static ExecutorType defaultExecutor();
 
 private:
     static std::string parseEnabled(const std::string &str, std::tuple<SimpleEnableGroup<Severity>, SimpleEnableGroup<Checks>> &groups);
     std::string applyEnabled(const std::string &str, bool enable);
+    std::map<std::string, std::string> mMisraRuleTexts;
 };
 
 /// @}
