@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2024 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -208,7 +208,7 @@ class CPPCHECKLIB Variable {
      * @param isContainer Is the array container-like?
      * @return true if array, false if not
      */
-    bool arrayDimensions(const Settings* settings, bool& isContainer);
+    bool arrayDimensions(const Settings& settings, bool& isContainer);
 
 public:
     Variable(const Token *name_, const Token *start_, const Token *end_,
@@ -899,7 +899,7 @@ public:
     void isConstexpr(bool state) {
         setFlag(fIsConstexpr, state);
     }
-    bool isSafe(const Settings *settings) const;
+    bool isSafe(const Settings &settings) const;
 
     const Token* tokenDef{};          ///< function name token in class definition
     const Token* argDef{};            ///< function argument start '(' in class definition
@@ -1003,7 +1003,7 @@ private:
         setFlag(fIsVolatile, state);
     }
     void hasTrailingReturnType(bool state) {
-        return setFlag(fHasTrailingReturnType, state);
+        setFlag(fHasTrailingReturnType, state);
     }
     void isInlineKeyword(bool state) {
         setFlag(fIsInlineKeyword, state);
@@ -1146,7 +1146,7 @@ public:
                      const Scope *scope_, const Settings* settings);
 
     /** @brief initialize varlist */
-    void getVariableList(const Settings* settings);
+    void getVariableList(const Settings& settings);
 
     const Function *getDestructor() const;
 
@@ -1167,7 +1167,7 @@ public:
      * @param settings Settings
      * @return pointer to last token
      */
-    const Token *checkVariable(const Token *tok, AccessControl varaccess, const Settings* settings);
+    const Token *checkVariable(const Token *tok, AccessControl varaccess, const Settings& settings);
 
     /**
      * @brief get variable from name
@@ -1176,7 +1176,7 @@ public:
      */
     const Variable *getVariable(const std::string &varname) const;
 
-    const Token * addEnum(const Token * tok, bool isCpp);
+    const Token * addEnum(const Token * tok);
 
     const Scope *findRecordInBase(const std::string &name) const;
 
@@ -1195,7 +1195,7 @@ private:
     void findFunctionInBase(const std::string & name, nonneg int args, std::vector<const Function *> & matches) const;
 
     /** @brief initialize varlist */
-    void getVariableList(const Settings* settings, const Token *start, const Token *end);
+    void getVariableList(const Settings& settings, const Token *start, const Token *end);
 };
 
 enum class Reference {
@@ -1232,6 +1232,7 @@ public:
     nonneg int bits{};                         ///< bitfield bitcount
     nonneg int pointer{};                      ///< 0=>not pointer, 1=>*, 2=>**, 3=>***, etc
     nonneg int constness{};                    ///< bit 0=data, bit 1=*, bit 2=**
+    nonneg int volatileness{};                 ///< bit 0=data, bit 1=*, bit 2=**
     Reference reference = Reference::None;     ///< Is the outermost indirection of this type a reference or rvalue
     ///< reference or not? pointer=2, Reference=LValue would be a T**&
     const Scope* typeScope{};                  ///< if the type definition is seen this point out the type scope
@@ -1258,6 +1259,13 @@ public:
         pointer(p),
         constness(c)
     {}
+    ValueType(Sign s, Type t, nonneg int p, nonneg int c, nonneg int v)
+        : sign(s),
+        type(t),
+        pointer(p),
+        constness(c),
+        volatileness(v)
+    {}
     ValueType(Sign s, Type t, nonneg int p, nonneg int c, std::string otn)
         : sign(s),
         type(t),
@@ -1294,6 +1302,8 @@ public:
 
     bool isConst(nonneg int indirect = 0) const;
 
+    bool isVolatile(nonneg int indirect = 0) const;
+
     MathLib::bigint typeSize(const Platform &platform, bool p=false) const;
 
     /// Check if type is the same ignoring const and references
@@ -1302,14 +1312,14 @@ public:
     std::string str() const;
     std::string dump() const;
 
-    void setDebugPath(const Token* tok, SourceLocation ctx, SourceLocation local = SourceLocation::current());
+    void setDebugPath(const Token* tok, SourceLocation ctx, const SourceLocation &local = SourceLocation::current());
 };
 
 
 class CPPCHECKLIB SymbolDatabase {
     friend class TestSymbolDatabase;
 public:
-    SymbolDatabase(Tokenizer& tokenizer, const Settings& settings, ErrorLogger* errorLogger);
+    SymbolDatabase(Tokenizer& tokenizer, const Settings& settings, ErrorLogger& errorLogger);
     ~SymbolDatabase();
 
     /** @brief Information about all namespaces/classes/structures */
@@ -1377,19 +1387,11 @@ public:
     void printVariable(const Variable *var, const char *indent) const;
     void printXml(std::ostream &out) const;
 
-    bool isCPP() const;
-
     /*
      * @brief Do a sanity check
      */
     void validate() const;
 
-    void validateExecutableScopes() const;
-    /**
-     * @brief Check variable list, e.g. variables w/o scope
-     */
-    void validateVariables() const;
-
     /** Set valuetype in provided tokenlist */
     void setValueTypeInTokenList(bool reportDebugWarnings, Token *tokens=nullptr);
 
@@ -1433,11 +1435,11 @@ private:
 
     void debugSymbolDatabase() const;
 
-    void addClassFunction(Scope **scope, const Token **tok, const Token *argStart);
+    void addClassFunction(Scope *&scope, const Token *&tok, const Token *argStart);
     static Function *addGlobalFunctionDecl(Scope*& scope, const Token* tok, const Token *argStart, const Token* funcStart);
     Function *addGlobalFunction(Scope*& scope, const Token*& tok, const Token *argStart, const Token* funcStart);
-    void addNewFunction(Scope **scope, const Token **tok);
-    bool isFunction(const Token *tok, const Scope* outerScope, const Token **funcStart, const Token **argStart, const Token** declEnd) const;
+    void addNewFunction(Scope *&scope, const Token *&tok);
+    bool isFunction(const Token *tok, const Scope* outerScope, const Token *&funcStart, const Token *&argStart, const Token*& declEnd) const;
     const Type *findTypeInNested(const Token *startTok, const Scope *startScope) const;
     const Scope *findNamespace(const Token * tok, const Scope * scope) const;
     static Function *findFunctionInScope(const Token *func, const Scope *ns, const std::string & path, nonneg int path_length);
@@ -1448,18 +1450,24 @@ private:
 
     void fixVarId(VarIdMap & varIds, const Token * vartok, Token * membertok, const Variable * membervar);
 
-    /** Whether iName is a keyword as defined in http://en.cppreference.com/w/c/keyword and http://en.cppreference.com/w/cpp/keyword*/
-    bool isReservedName(const std::string& iName) const;
+    /** Whether the token is a keyword as defined in http://en.cppreference.com/w/c/keyword and http://en.cppreference.com/w/cpp/keyword*/
+    static bool isReservedName(const Token* tok);
 
     const Enumerator * findEnumerator(const Token * tok, std::set<std::string>& tokensThatAreNotEnumeratorValues) const;
 
-    void setValueType(Token* tok, const ValueType& valuetype, SourceLocation loc = SourceLocation::current());
-    void setValueType(Token* tok, const Variable& var, SourceLocation loc = SourceLocation::current());
-    void setValueType(Token* tok, const Enumerator& enumerator, SourceLocation loc = SourceLocation::current());
+    void setValueType(Token* tok, const ValueType& valuetype, const SourceLocation &loc = SourceLocation::current());
+    void setValueType(Token* tok, const Variable& var, const SourceLocation &loc = SourceLocation::current());
+    void setValueType(Token* tok, const Enumerator& enumerator, const SourceLocation &loc = SourceLocation::current());
+
+    void validateExecutableScopes() const;
+    /**
+     * @brief Check variable list, e.g. variables w/o scope
+     */
+    void validateVariables() const;
 
     Tokenizer& mTokenizer;
     const Settings &mSettings;
-    ErrorLogger *mErrorLogger;
+    ErrorLogger &mErrorLogger;
 
     /** variable symbol table */
     std::vector<const Variable *> mVariableList;
@@ -1467,7 +1475,6 @@ private:
     /** list for missing types */
     std::list<Type> mBlankTypes;
 
-    bool mIsCpp;
     ValueType::Sign mDefaultSignedness;
 };
 
