@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2024 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,7 +24,6 @@
 #include "config.h"
 #include "tokenlist.h"
 
-#include <cassert>
 #include <iosfwd>
 #include <list>
 #include <map>
@@ -37,29 +36,24 @@ class TimerResults;
 class Token;
 class TemplateSimplifier;
 class ErrorLogger;
-class Preprocessor;
+struct Directive; // IWYU pragma: keep
 enum class Severity;
 
-namespace simplecpp {
-    class TokenList;
-}
-
 /// @addtogroup Core
 /// @{
 
 /** @brief The main purpose is to tokenize the source code. It also has functions that simplify the token list */
 class CPPCHECKLIB Tokenizer {
 
-    friend class TestSimplifyTokens;
-    friend class TestSimplifyTypedef;
-    friend class TestSimplifyUsing;
-    friend class TestTokenizer;
     friend class SymbolDatabase;
-    friend class TestSimplifyTemplate;
     friend class TemplateSimplifier;
 
+    friend class TestSimplifyTemplate;
+    friend class TestSimplifyTypedef;
+    friend class TestTokenizer;
+
 public:
-    explicit Tokenizer(const Settings * settings, ErrorLogger *errorLogger = nullptr, const Preprocessor *preprocessor = nullptr);
+    explicit Tokenizer(const Settings & settings, ErrorLogger &errorLogger);
     ~Tokenizer();
 
     void setTimerResults(TimerResults *tr) {
@@ -84,35 +78,9 @@ public:
      */
     bool isScopeNoReturn(const Token *endScopeToken, bool *unknown = nullptr) const;
 
-    bool createTokens(std::istream &code, const std::string& FileName);
-    void createTokens(simplecpp::TokenList&& tokenList);
-
     bool simplifyTokens1(const std::string &configuration);
-    /**
-     * Tokenize code
-     * @param code input stream for code, e.g.
-     * \code
-     * #file "p.h"
-     * class Foo
-     * {
-     * private:
-     * void Bar();
-     * };
-     *
-     * #endfile
-     * void Foo::Bar()
-     * {
-     * }
-     * \endcode
-     *
-     * @param FileName The filename
-     * @param configuration E.g. "A" for code where "#ifdef A" is true
-     * @return false if source code contains syntax errors
-     */
-    bool tokenize(std::istream &code,
-                  const char FileName[],
-                  const std::string &configuration = emptyString);
 
+private:
     /** Set variable id */
     void setVarId();
     void setVarIdPass1();
@@ -147,7 +115,7 @@ public:
      */
     void splitTemplateRightAngleBrackets(bool check);
 
-
+public:
     /**
      * Calculates sizeof value for given type.
      * @param type Token which will contain e.g. "int", "*", or string.
@@ -156,6 +124,7 @@ public:
     nonneg int sizeOfType(const Token* type) const;
     nonneg int sizeOfType(const std::string& type) const;
 
+private:
     void simplifyDebug();
 
     /** Simplify assignment where rhs is a block : "x=({123;});" => "{x=123;}" */
@@ -359,6 +328,7 @@ public:
      */
     static std::string simplifyString(const std::string &source);
 
+public:
     /**
      * is token pointing at function head?
      * @param tok         A '(' or ')' token in a possible function head
@@ -367,13 +337,10 @@ public:
      */
     static const Token * isFunctionHead(const Token *tok, const std::string &endsWith);
 
-    const Preprocessor *getPreprocessor() const {
-        assert(mPreprocessor);
-        return mPreprocessor;
-    }
-
     bool hasIfdef(const Token *start, const Token *end) const;
 
+    bool isPacked(const Token * bodyStart) const;
+
 private:
 
     /** Simplify pointer to standard type (C only) */
@@ -398,6 +365,11 @@ private:
      */
     void createLinks2();
 
+    /**
+     * Set isCast() for C++ casts
+     */
+    void markCppCasts();
+
 public:
 
     /** Syntax error */
@@ -566,7 +538,7 @@ private:
     void reportError(const Token* tok, const Severity severity, const std::string& id, const std::string& msg, bool inconclusive = false) const;
     void reportError(const std::list<const Token*>& callstack, Severity severity, const std::string& id, const std::string& msg, bool inconclusive = false) const;
 
-    bool duplicateTypedef(Token **tokPtr, const Token *name, const Token *typeDef) const;
+    bool duplicateTypedef(Token *&tokPtr, const Token *name, const Token *typeDef) const;
 
     void unsupportedTypedef(const Token *tok) const;
 
@@ -640,7 +612,7 @@ public:
      */
     static const Token * startOfExecutableScope(const Token * tok);
 
-    const Settings *getSettings() const {
+    const Settings &getSettings() const {
         return mSettings;
     }
 
@@ -652,6 +624,8 @@ public:
     /** Disable assignment operator */
     Tokenizer &operator=(const Tokenizer &) = delete;
 
+    void setDirectives(std::list<Directive> directives);
+
 private:
     const Token *processFunc(const Token *tok2, bool inOperator) const;
     Token *processFunc(Token *tok2, bool inOperator);
@@ -668,10 +642,10 @@ private:
     void setPodTypes();
 
     /** settings */
-    const Settings * const mSettings;
+    const Settings & mSettings;
 
     /** errorlogger */
-    ErrorLogger* const mErrorLogger;
+    ErrorLogger& mErrorLogger;
 
     /** Symbol database that all checks etc can use */
     SymbolDatabase* mSymbolDatabase{};
@@ -694,6 +668,8 @@ private:
     };
     std::vector<TypedefInfo> mTypedefInfo;
 
+    std::list<Directive> mDirectives;
+
     /** variable count */
     nonneg int mVarId{};
 
@@ -704,8 +680,6 @@ private:
      * TimerResults
      */
     TimerResults* mTimerResults{};
-
-    const Preprocessor * const mPreprocessor;
 };
 
 /// @}
