@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2024 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
  */
 
 //---------------------------------------------------------------------------
+
 #include "tokenlist.h"
 
 #include "astutils.h"
@@ -40,16 +41,28 @@
 
 #include <simplecpp.h>
 
+//#define N_ASSERT_LANG
+
+#ifndef N_ASSERT_LANG
+#include <cassert>
+#define ASSERT_LANG(x) assert(x)
+#else
+#define ASSERT_LANG(x)
+#endif
+
 // How many compileExpression recursions are allowed?
 // For practical code this could be endless. But in some special torture test
 // there needs to be a limit.
 static constexpr int AST_MAX_DEPTH = 150;
 
 
-TokenList::TokenList(const Settings* settings) :
-    mSettings(settings)
+TokenList::TokenList(const Settings* settings)
+    : mTokensFrontBack(*this)
+    , mSettings(settings)
 {
-    mTokensFrontBack.list = this;
+    if (mSettings && (mSettings->enforcedLang != Standards::Language::None)) {
+        mLang = mSettings->enforcedLang;
+    }
 }
 
 TokenList::~TokenList()
@@ -80,12 +93,16 @@ void TokenList::deallocateTokens()
 
 void TokenList::determineCppC()
 {
-    if (!mSettings) {
-        mIsC = Path::isC(getSourceFilePath());
-        mIsCpp = Path::isCPP(getSourceFilePath());
-    } else {
-        mIsC = mSettings->enforcedLang == Settings::Language::C || (mSettings->enforcedLang == Settings::Language::None && Path::isC(getSourceFilePath()));
-        mIsCpp = mSettings->enforcedLang == Settings::Language::CPP || (mSettings->enforcedLang == Settings::Language::None && Path::isCPP(getSourceFilePath()));
+    // only try to determine if it wasn't enforced
+    if (mLang == Standards::Language::None) {
+        mLang = Path::identify(getSourceFilePath());
+        // TODO: cannot enable assert as this might occur for unknown extensions
+        //ASSERT_LANG(mLang != Standards::Language::None);
+        if (mLang == Standards::Language::None) {
+            // TODO: should default to C instead like we do for headers
+            // default to C++
+            mLang = Standards::Language::CPP;
+        }
     }
 }
 
@@ -147,7 +164,7 @@ void TokenList::addtoken(const std::string& str, const nonneg int lineno, const
     if (mTokensFrontBack.back) {
         mTokensFrontBack.back->insertToken(str);
     } else {
-        mTokensFrontBack.front = new Token(&mTokensFrontBack);
+        mTokensFrontBack.front = new Token(mTokensFrontBack);
         mTokensFrontBack.back = mTokensFrontBack.front;
         mTokensFrontBack.back->str(str);
     }
@@ -165,7 +182,7 @@ void TokenList::addtoken(const std::string& str, const Token *locationTok)
     if (mTokensFrontBack.back) {
         mTokensFrontBack.back->insertToken(str);
     } else {
-        mTokensFrontBack.front = new Token(&mTokensFrontBack);
+        mTokensFrontBack.front = new Token(mTokensFrontBack);
         mTokensFrontBack.back = mTokensFrontBack.front;
         mTokensFrontBack.back->str(str);
     }
@@ -183,7 +200,7 @@ void TokenList::addtoken(const Token * tok, const nonneg int lineno, const nonne
     if (mTokensFrontBack.back) {
         mTokensFrontBack.back->insertToken(tok->str(), tok->originalName());
     } else {
-        mTokensFrontBack.front = new Token(&mTokensFrontBack);
+        mTokensFrontBack.front = new Token(mTokensFrontBack);
         mTokensFrontBack.back = mTokensFrontBack.front;
         mTokensFrontBack.back->str(tok->str());
         if (!tok->originalName().empty())
@@ -204,7 +221,7 @@ void TokenList::addtoken(const Token *tok, const Token *locationTok)
     if (mTokensFrontBack.back) {
         mTokensFrontBack.back->insertToken(tok->str(), tok->originalName());
     } else {
-        mTokensFrontBack.front = new Token(&mTokensFrontBack);
+        mTokensFrontBack.front = new Token(mTokensFrontBack);
         mTokensFrontBack.back = mTokensFrontBack.front;
         mTokensFrontBack.back->str(tok->str());
         if (!tok->originalName().empty())
@@ -223,13 +240,13 @@ void TokenList::addtoken(const Token *tok)
         return;
 
     if (mTokensFrontBack.back) {
-        mTokensFrontBack.back->insertToken(tok->str(), tok->originalName());
+        mTokensFrontBack.back->insertToken(tok->str(), tok->originalName(), tok->getMacroName());
     } else {
-        mTokensFrontBack.front = new Token(&mTokensFrontBack);
+        mTokensFrontBack.front = new Token(mTokensFrontBack);
         mTokensFrontBack.back = mTokensFrontBack.front;
         mTokensFrontBack.back->str(tok->str());
-        if (!tok->originalName().empty())
-            mTokensFrontBack.back->originalName(tok->originalName());
+        mTokensFrontBack.back->originalName(tok->originalName());
+        mTokensFrontBack.back->setMacroName(tok->getMacroName());
     }
 
     mTokensFrontBack.back->flags(tok->flags());
@@ -317,8 +334,31 @@ void TokenList::insertTokens(Token *dest, const Token *src, nonneg int n)
 
 bool TokenList::createTokens(std::istream &code, const std::string& file0)
 {
+    ASSERT_LANG(!file0.empty());
+
     appendFileIfNew(file0);
 
+    return createTokensInternal(code, file0);
+}
+
+//---------------------------------------------------------------------------
+
+bool TokenList::createTokens(std::istream &code, Standards::Language lang)
+{
+    ASSERT_LANG(lang != Standards::Language::None);
+    if (mLang == Standards::Language::None) {
+        mLang = lang;
+    } else {
+        ASSERT_LANG(lang == mLang);
+    }
+
+    return createTokensInternal(code, "");
+}
+
+//---------------------------------------------------------------------------
+
+bool TokenList::createTokensInternal(std::istream &code, const std::string& file0)
+{
     simplecpp::OutputList outputList;
     simplecpp::TokenList tokens(code, mFiles, file0, &outputList);
 
@@ -355,7 +395,7 @@ void TokenList::createTokens(simplecpp::TokenList&& tokenList)
         if (mTokensFrontBack.back) {
             mTokensFrontBack.back->insertToken(str);
         } else {
-            mTokensFrontBack.front = new Token(&mTokensFrontBack);
+            mTokensFrontBack.front = new Token(mTokensFrontBack);
             mTokensFrontBack.back = mTokensFrontBack.front;
             mTokensFrontBack.back->str(str);
         }
@@ -452,6 +492,9 @@ static bool iscast(const Token *tok, bool cpp)
     if (Token::simpleMatch(tok->link(), ") ( )"))
         return false;
 
+    if (Token::Match(tok->link(), ") %assign%|,|..."))
+        return false;
+
     if (tok->previous() && tok->previous()->isName() && tok->previous()->str() != "return" &&
         (!cpp || !Token::Match(tok->previous(), "delete|throw")))
         return false;
@@ -573,8 +616,12 @@ static bool iscpp11init_impl(const Token * const tok)
     }
 
     auto isCaseStmt = [](const Token* colonTok) {
-        if (!Token::Match(colonTok->tokAt(-1), "%name%|%num%|%char% :"))
+        if (!Token::Match(colonTok->tokAt(-1), "%name%|%num%|%char%|) :"))
             return false;
+        if (const Token* castTok = colonTok->linkAt(-1)) {
+            if (Token::simpleMatch(castTok->astParent(), "case"))
+                return true;
+        }
         const Token* caseTok = colonTok->tokAt(-2);
         while (caseTok && Token::Match(caseTok->tokAt(-1), "::|%name%"))
             caseTok = caseTok->tokAt(-1);
@@ -642,7 +689,7 @@ static void compileUnaryOp(Token *&tok, AST_state& state, void (*f)(Token *&tok,
         state.depth--;
     }
 
-    if (!state.op.empty()) {
+    if (!state.op.empty() && (!precedes(state.op.top(), unaryop) || unaryop->isIncDecOp() || Token::Match(unaryop, "[({[]"))) { // nullary functions, empty lists/arrays
         unaryop->astOperand1(state.op.top());
         state.op.pop();
     }
@@ -702,7 +749,7 @@ static void compileTerm(Token *&tok, AST_state& state)
             tok = tok->next();
         } while (Token::Match(tok, "%name%|%str%"));
     } else if (tok->isName()) {
-        if (Token::Match(tok, "return|case") || (state.cpp && tok->str() == "throw")) {
+        if (Token::Match(tok, "return|case") || (state.cpp && (tok->str() == "throw"))) {
             if (tok->str() == "case")
                 state.inCase = true;
             const bool tokIsReturn = tok->str() == "return";
@@ -956,7 +1003,7 @@ static void compilePrecedence2(Token *&tok, AST_state& state)
                     Token* const curlyBracket = squareBracket->link()->next();
                     squareBracket->astOperand1(curlyBracket);
                     state.op.push(squareBracket);
-                    tok = curlyBracket->link()->next();
+                    tok = curlyBracket->link() ? curlyBracket->link()->next() : nullptr;
                     continue;
                 }
             }
@@ -1113,6 +1160,10 @@ static void compilePrecedence3(Token *&tok, AST_state& state)
                 compilePrecedence2(tok, state);
             }
             compileUnaryOp(newtok, state, nullptr);
+            if (Token::simpleMatch(newtok->previous(), ":: new")) {
+                newtok->previous()->astOperand1(newtok);
+                state.op.pop();
+            }
             if (innertype && Token::simpleMatch(tok, ") ,"))
                 tok = tok->next();
         } else if (state.cpp && Token::Match(tok, "delete %name%|*|&|::|(|[")) {
@@ -1122,6 +1173,10 @@ static void compilePrecedence3(Token *&tok, AST_state& state)
                 tok = tok->link()->next();
             compilePrecedence3(tok, state);
             compileUnaryOp(tok2, state, nullptr);
+            if (Token::simpleMatch(tok2->previous(), ":: delete")) {
+                tok2->previous()->astOperand1(tok2);
+                state.op.pop();
+            }
         }
         // TODO: Handle sizeof
         else break;
@@ -1366,12 +1421,21 @@ const Token* findLambdaEndTokenWithoutAST(const Token* tok) {
     tok = tok->link()->next();
     if (Token::simpleMatch(tok, "(") && tok->link())
         tok = tok->link()->next();
+    if (Token::simpleMatch(tok, ".")) { // trailing return type
+        tok = tok->next();
+        while (Token::Match(tok, "%type%|%name%|::|&|&&|*|<|(")) {
+            if (tok->link())
+                tok = tok->link()->next();
+            else
+                tok = tok->next();
+        }
+    }
     if (!(Token::simpleMatch(tok, "{") && tok->link()))
         return nullptr;
     return tok->link()->next();
 }
 
-static Token * createAstAtToken(Token *tok, bool cpp);
+static Token * createAstAtToken(Token *tok);
 
 // Compile inner expressions inside inner ({..}) and lambda bodies
 static void createAstAtTokenInner(Token * const tok1, const Token *endToken, bool cpp)
@@ -1392,7 +1456,7 @@ static void createAstAtTokenInner(Token * const tok1, const Token *endToken, boo
             }
             if (!hasAst) {
                 for (; tok && tok != endToken && tok != endToken2; tok = tok ? tok->next() : nullptr)
-                    tok = createAstAtToken(tok, cpp);
+                    tok = createAstAtToken(tok);
             }
         } else if (cpp && tok->str() == "[") {
             if (isLambdaCaptureList(tok)) {
@@ -1402,7 +1466,7 @@ static void createAstAtTokenInner(Token * const tok1, const Token *endToken, boo
                 const Token * const endToken2 = tok->link();
                 tok = tok->next();
                 for (; tok && tok != endToken && tok != endToken2; tok = tok ? tok->next() : nullptr)
-                    tok = createAstAtToken(tok, cpp);
+                    tok = createAstAtToken(tok);
             }
         }
         else if (Token::simpleMatch(tok, "( * ) [")) {
@@ -1444,8 +1508,9 @@ static Token * findAstTop(Token *tok1, const Token *tok2)
     return nullptr;
 }
 
-static Token * createAstAtToken(Token *tok, bool cpp)
+static Token * createAstAtToken(Token *tok)
 {
+    const bool cpp = tok->isCpp();
     // skip function pointer declaration
     if (Token::Match(tok, "%type% %type%") && !Token::Match(tok, "return|throw|new|delete")) {
         Token* tok2 = tok->tokAt(2);
@@ -1528,7 +1593,7 @@ static Token * createAstAtToken(Token *tok, bool cpp)
             AST_state state1(cpp);
             compileExpression(tok2, state1);
             if (Token::Match(init1, "( !!{")) {
-                for (Token *tok3 = init1; tok3 != tok3->link(); tok3 = tok3->next()) {
+                for (Token *tok3 = init1; tok3 && tok3 != tok3->link(); tok3 = tok3->next()) {
                     if (tok3->astParent()) {
                         while (tok3->astParent())
                             tok3 = tok3->astParent();
@@ -1673,6 +1738,8 @@ static Token * createAstAtToken(Token *tok, bool cpp)
         AST_state state(cpp);
         if (Token::Match(tok, "%name% ("))
             state.functionCallEndPar = tok->linkAt(1);
+        if (Token::simpleMatch(tok->tokAt(-1), "::") && (!tok->tokAt(-2) || !tok->tokAt(-2)->isName()))
+            tok = tok->tokAt(-1);
         compileExpression(tok, state);
         Token * const endToken = tok;
         if (endToken == tok1 || !endToken)
@@ -1701,7 +1768,10 @@ static Token * createAstAtToken(Token *tok, bool cpp)
 void TokenList::createAst() const
 {
     for (Token *tok = mTokensFrontBack.front; tok; tok = tok ? tok->next() : nullptr) {
-        tok = createAstAtToken(tok, isCPP());
+        Token* const nextTok = createAstAtToken(tok);
+        if (precedes(nextTok, tok))
+            throw InternalError(tok, "Syntax Error: Infinite loop when creating AST.", InternalError::AST);
+        tok = nextTok;
     }
 }
 
@@ -1718,10 +1788,10 @@ namespace {
     };
 }
 
-void TokenList::validateAst() const
+void TokenList::validateAst(bool print) const
 {
     OnException oe{[&] {
-            if (mSettings && mSettings->debugnormal)
+            if (print)
                 mTokensFrontBack.front->printOut();
         }};
     // Check for some known issues in AST to avoid crash/hang later on
@@ -1763,9 +1833,13 @@ void TokenList::validateAst() const
             tok = tok->link();
             continue;
         }
-        if (tok->isCast() && tok->astOperand1() && tok->link()) { // skip casts (not part of the AST)
-            tok = tok->link();
-            continue;
+        if (tok->isCast()) {
+            if (!tok->astOperand2() && precedes(tok->astOperand1(), tok))
+                throw InternalError(tok, "AST broken: '" + tok->str() + "' has improper operand.", InternalError::AST);
+            if (tok->astOperand1() && tok->link()) { // skip casts (not part of the AST)
+                tok = tok->link();
+                continue;
+            }
         }
 
         if (findLambdaEndToken(tok)) { // skip lambda captures
@@ -1850,7 +1924,7 @@ void TokenList::simplifyPlatformTypes()
     if (!mSettings)
         return;
 
-    const bool isCPP11  = mSettings->standards.cpp >= Standards::CPP11;
+    const bool isCPP11 = isCPP() && (mSettings->standards.cpp >= Standards::CPP11);
 
     enum { isLongLong, isLong, isInt } type;
 
@@ -1992,7 +2066,7 @@ void TokenList::simplifyStdType()
             continue;
         }
 
-        if (Token::Match(tok, "char|short|int|long|unsigned|signed|double|float") || (mSettings->standards.c >= Standards::C99 && Token::Match(tok, "complex|_Complex"))) {
+        if (Token::Match(tok, "char|short|int|long|unsigned|signed|double|float") || (isC() && (!mSettings || (mSettings->standards.c >= Standards::C99)) && Token::Match(tok, "complex|_Complex"))) {
             bool isFloat= false;
             bool isSigned = false;
             bool isUnsigned = false;
@@ -2015,7 +2089,7 @@ void TokenList::simplifyStdType()
                 else if (Token::Match(tok2, "float|double")) {
                     isFloat = true;
                     typeSpec = tok2;
-                } else if (mSettings->standards.c >= Standards::C99 && Token::Match(tok2, "complex|_Complex"))
+                } else if (isC() && (!mSettings || (mSettings->standards.c >= Standards::C99)) && Token::Match(tok2, "complex|_Complex"))
                     isComplex = !isFloat || tok2->str() == "_Complex" || Token::Match(tok2->next(), "*|&|%name%"); // Ensure that "complex" is not the variables name
                 else if (Token::Match(tok2, "char|int")) {
                     if (!typeSpec)
@@ -2053,7 +2127,7 @@ void TokenList::simplifyStdType()
 
 bool TokenList::isKeyword(const std::string &str) const
 {
-    if (mIsCpp) {
+    if (isCPP()) {
         // TODO: integrate into keywords?
         // types and literals are not handled as keywords
         static const std::unordered_set<std::string> cpp_types = {"bool", "false", "true"};
@@ -2083,3 +2157,33 @@ bool TokenList::isKeyword(const std::string &str) const
     static const auto& latest_c_keywords = Keywords::getAll(Standards::cstd_t::CLatest);
     return latest_c_keywords.find(str) != latest_c_keywords.end();
 }
+
+bool TokenList::isC() const
+{
+    ASSERT_LANG(mLang != Standards::Language::None);
+
+    // TODO: remove the fallback
+    if (mLang == Standards::Language::None)
+        return false; // treat as C++ by default
+
+    return mLang == Standards::Language::C;
+}
+
+bool TokenList::isCPP() const
+{
+    ASSERT_LANG(mLang != Standards::Language::None);
+
+    // TODO: remove the fallback
+    if (mLang == Standards::Language::None)
+        return true; // treat as C++ by default
+
+    return mLang == Standards::Language::CPP;
+}
+
+void TokenList::setLang(Standards::Language lang)
+{
+    ASSERT_LANG(lang != Standards::Language::None);
+    ASSERT_LANG(mLang == Standards::Language::None);
+
+    mLang = lang;
+}
