@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2024 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,15 +22,13 @@
 #include "config.h"
 
 SUPPRESS_WARNING_CLANG_PUSH("-Wzero-as-null-pointer-constant")
-SUPPRESS_WARNING_CLANG_PUSH("-Wextra-semi-stmt")
-SUPPRESS_WARNING_CLANG_PUSH("-Wsuggest-override")
 SUPPRESS_WARNING_CLANG_PUSH("-Wsuggest-destructor-override")
+SUPPRESS_WARNING_CLANG_PUSH("-Winconsistent-missing-destructor-override")
 
-#include <tinyxml2.h>
+#include <tinyxml2.h> // IWYU pragma: export
 
 SUPPRESS_WARNING_CLANG_POP
 SUPPRESS_WARNING_CLANG_POP
 SUPPRESS_WARNING_CLANG_POP
-SUPPRESS_WARNING_CLANG_POP
 
 #endif // xmlH
