@@ -7,6 +7,8 @@
 // No warnings about bad library configuration, unmatched suppressions, etc. exitcode=0
 //
 
+// cppcheck-suppress-file valueFlowBailout
+
 #include <iostream>
 #include <opencv2/opencv.hpp>
 
@@ -14,6 +16,7 @@
 void validCode(const char* argStr)
 {
     cv::Mat image;
+    // cppcheck-suppress valueFlowBailoutIncompleteVar
     image = cv::imread(argStr, cv::IMREAD_COLOR);
     if (!image.data) {
         printf("No image data \n");
@@ -27,7 +30,8 @@ void validCode(const char* argStr)
     cvStr += " World";
     std::cout << cvStr;
 
-    char * pBuf = (char *)cv::fastMalloc(20); // cppcheck-suppress cstyleCast
+    // cppcheck-suppress [cstyleCast, unusedAllocatedMemory]
+    char * pBuf = (char *)cv::fastMalloc(20);
     cv::fastFree(pBuf);
 }
 
@@ -39,7 +43,9 @@ void ignoredReturnValue()
 
 void memleak()
 {
-    const char * pBuf = (char *)cv::fastMalloc(1000); // cppcheck-suppress cstyleCast
+    // cppcheck-suppress cstyleCast
+    const char * pBuf = (char *)cv::fastMalloc(1000);
+    // cppcheck-suppress [uninitdata, valueFlowBailoutIncompleteVar]
     std::cout << pBuf;
     // cppcheck-suppress memleak
 }
