@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2024 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,14 +16,11 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-
 #include "check64bit.h"
 #include "errortypes.h"
-#include "settings.h"
 #include "fixture.h"
-#include "tokenize.h"
-
-#include <sstream> // IWYU pragma: keep
+#include "helpers.h"
+#include "settings.h"
 
 class Test64BitPortability : public TestFixture {
 public:
@@ -44,13 +41,9 @@ private:
 
 #define check(code) check_(code, __FILE__, __LINE__)
     void check_(const char code[], const char* file, int line) {
-        // Clear the error buffer..
-        errout.str("");
-
         // Tokenize..
-        Tokenizer tokenizer(&settings, this);
-        std::istringstream istr(code);
-        ASSERT_LOC(tokenizer.tokenize(istr, "test.cpp"), file, line);
+        SimpleTokenizer tokenizer(settings, *this);
+        ASSERT_LOC(tokenizer.tokenize(code), file, line);
 
         // Check char variable usage..
         Check64BitPortability check64BitPortability(&tokenizer, &settings, this);
@@ -63,13 +56,13 @@ private:
               "void f() {\n"
               "    CharArray foo = \"\";\n"
               "}");
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
 
         check("struct T { std::vector<int>*a[2][2]; };\n" // #11560
               "void f(T& t, int i, int j) {\n"
               "    t.a[i][j] = new std::vector<int>;\n"
               "}\n");
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
     }
 
     void novardecl() {
@@ -78,7 +71,7 @@ private:
               "{\n"
               "    a = p;\n"
               "}");
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
     }
 
     void functionpar() {
@@ -87,65 +80,65 @@ private:
               "    int a = p;\n"
               "    return a + 4;\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:3]: (portability) Assigning a pointer to an integer is not portable.\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:3]: (portability) Assigning a pointer to an integer is not portable.\n", errout_str());
 
         check("int foo(int p[])\n"
               "{\n"
               "    int a = p;\n"
               "    return a + 4;\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:3]: (portability) Assigning a pointer to an integer is not portable.\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:3]: (portability) Assigning a pointer to an integer is not portable.\n", errout_str());
 
         check("int foo(int p[])\n"
               "{\n"
               "    int *a = p;\n"
               "    return a;\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:4]: (portability) Returning an address value in a function with integer return type is not portable.\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:4]: (portability) Returning an address value in a function with integer return type is not portable.\n", errout_str());
 
         check("void foo(int x)\n"
               "{\n"
               "    int *p = x;\n"
               "    *p = 0;\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:3]: (portability) Assigning an integer to a pointer is not portable.\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:3]: (portability) Assigning an integer to a pointer is not portable.\n", errout_str());
 
         check("int f(const char *p) {\n" // #4659
               "    return 6 + p[2] * 256;\n"
               "}");
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
 
         check("int foo(int *p) {\n" // #6096
               "    bool a = p;\n"
               "    return a;\n"
               "}");
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
 
         check("std::array<int,2> f();\n"
               "void g() {\n"
               "    std::array<int, 2> a = f();\n"
               "}");
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
 
         check("std::array<int,2> f(int x);\n"
               "void g(int i) {\n"
               "    std::array<int, 2> a = f(i);\n"
               "}");
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
 
         check("typedef std::array<int, 2> Array;\n"
               "Array f(int x);\n"
               "void g(int i) {\n"
               "    Array a = f(i);\n"
               "}");
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
 
         check("typedef std::array<int, 2> Array;\n"
               "Array f();\n"
               "void g(int i) {\n"
               "    Array a = f();\n"
               "}");
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
 
         check("struct S {\n" // #9951
               "    enum E { E0 };\n"
@@ -154,12 +147,12 @@ private:
               "void f() {\n"
               "    std::array<double, 1> a = S::g(S::E::E0);\n"
               "}\n");
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
 
         check("char* f(char* p) {\n"
               "    return p ? p : 0;\n"
               "}\n");
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
     }
 
     void structmember() {
@@ -167,7 +160,7 @@ private:
               "void f(struct Foo *foo) {\n"
               "    int i = foo->p;\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:3]: (portability) Assigning a pointer to an integer is not portable.\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:3]: (portability) Assigning a pointer to an integer is not portable.\n", errout_str());
 
         check("struct S {\n" // #10145
               "    enum class E { e1, e2 };\n"
@@ -177,7 +170,7 @@ private:
               "void f(S& s) {\n"
               "    s.e = S::E::e1;\n"
               "}\n");
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
     }
 
     void ptrcompare() {
@@ -185,7 +178,7 @@ private:
         check("void foo(int *p) {\n"
               "    int a = (p != NULL);\n"
               "}");
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
     }
 
     void ptrarithmetic() {
@@ -194,74 +187,74 @@ private:
               "    int x = 10;\n"
               "    int *a = p + x;\n"
               "}");
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
 
         check("void foo(int *p) {\n"
               "    int x = 10;\n"
               "    int *a = x + p;\n"
               "}");
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
 
         check("void foo(int *p) {\n"
               "    int x = 10;\n"
               "    int *a = x * x;\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:3]: (portability) Assigning an integer to a pointer is not portable.\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:3]: (portability) Assigning an integer to a pointer is not portable.\n", errout_str());
 
         check("void foo(int *start, int *end) {\n"
               "    int len;\n"
               "    int len = end + 10 - start;\n"
               "}");
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
     }
 
     void returnIssues() {
         check("void* foo(int i) {\n"
               "    return i;\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (portability) Returning an integer in a function with pointer return type is not portable.\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:2]: (portability) Returning an integer in a function with pointer return type is not portable.\n", errout_str());
 
         check("void* foo(int* i) {\n"
               "    return i;\n"
               "}");
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
 
         check("void* foo() {\n"
               "    return 0;\n"
               "}");
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
 
         check("int foo(int i) {\n"
               "    return i;\n"
               "}");
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
 
         check("struct Foo {};\n"
               "\n"
               "int* dostuff(Foo foo) {\n"
               "  return foo;\n"
               "}");
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
 
         check("int foo(char* c) {\n"
               "    return c;\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (portability) Returning an address value in a function with integer return type is not portable.\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:2]: (portability) Returning an address value in a function with integer return type is not portable.\n", errout_str());
 
         check("int foo(char* c) {\n"
               "    return 1+c;\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (portability) Returning an address value in a function with integer return type is not portable.\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:2]: (portability) Returning an address value in a function with integer return type is not portable.\n", errout_str());
 
         check("std::string foo(char* c) {\n"
               "    return c;\n"
               "}");
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
 
         check("int foo(char *a, char *b) {\n" // #4486
               "    return a + 1 - b;\n"
               "}");
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
 
         check("struct s {\n" // 4642
               "   int i;\n"
@@ -269,13 +262,13 @@ private:
               "int func(struct s *p) {\n"
               " return 1 + p->i;\n"
               "}");
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
 
         check("static void __iomem *f(unsigned int port_no) {\n"
               "  void __iomem *mmio = hpriv->mmio;\n"
               "  return mmio + (port_no * 0x80);\n"
               "}");
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
 
         // #7247: don't check return statements in nested functions..
         check("int foo() {\n"
@@ -283,7 +276,7 @@ private:
               "    const char * name() { return \"abc\"; }\n"
               "  } table;\n"
               "}");
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
 
         // #7451: Lambdas
         check("const int* test(std::vector<int> outputs, const std::string& text) {\n"
@@ -291,7 +284,7 @@ private:
               "     [&](int ele) { return \"test\" == text; });\n"
               "  return nullptr;\n"
               "}");
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
 
         check("struct S {\n" // #12159
               "    std::future<int> f() const {\n"
@@ -303,7 +296,7 @@ private:
               "    auto x = s->f();\n"
               "    return x.get();\n"
               "}\n");
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
     }
 };
 
