@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2024 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 #include "fixture.h"
 
 #include <string>
+#include <utility>
 #include <vector>
 
 
@@ -92,7 +93,7 @@ private:
 
     void onemasksamepathdifferentcase() const {
         std::vector<std::string> masks(1, "sRc/");
-        PathMatch match(masks, false);
+        PathMatch match(std::move(masks), false);
         ASSERT(match.match("srC/"));
     }
 
@@ -139,25 +140,25 @@ private:
 
     void twomasklongerpath1() const {
         std::vector<std::string> masks = { "src/", "module/" };
-        PathMatch match(masks);
+        PathMatch match(std::move(masks));
         ASSERT(!match.match("project/"));
     }
 
     void twomasklongerpath2() const {
         std::vector<std::string> masks = { "src/", "module/" };
-        PathMatch match(masks);
+        PathMatch match(std::move(masks));
         ASSERT(match.match("project/src/"));
     }
 
     void twomasklongerpath3() const {
         std::vector<std::string> masks = { "src/", "module/" };
-        PathMatch match(masks);
+        PathMatch match(std::move(masks));
         ASSERT(match.match("project/module/"));
     }
 
     void twomasklongerpath4() const {
         std::vector<std::string> masks = { "src/", "module/" };
-        PathMatch match(masks);
+        PathMatch match(std::move(masks));
         ASSERT(match.match("project/src/module/"));
     }
 
@@ -168,7 +169,7 @@ private:
 
     void filemaskdifferentcase() const {
         std::vector<std::string> masks(1, "foo.cPp");
-        PathMatch match(masks, false);
+        PathMatch match(std::move(masks), false);
         ASSERT(match.match("fOo.cpp"));
     }
 
