@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2024 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,17 +16,17 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-
 #include "errortypes.h"
+#include "fixture.h"
 #include "helpers.h"
 #include "platform.h"
 #include "settings.h"
-#include "fixture.h"
 #include "token.h"
 #include "tokenize.h"
+#include "tokenlist.h"
 #include "utils.h"
 
-#include <sstream> // IWYU pragma: keep
+#include <sstream>
 #include <string>
 #include <vector>
 
@@ -68,6 +68,7 @@ private:
         TEST_CASE(simplifyUsing27);
         TEST_CASE(simplifyUsing28);
         TEST_CASE(simplifyUsing29);
+        TEST_CASE(simplifyUsing30);
 
         TEST_CASE(simplifyUsing8970);
         TEST_CASE(simplifyUsing8971);
@@ -95,19 +96,20 @@ private:
 
 #define tok(...) tok_(__FILE__, __LINE__, __VA_ARGS__)
     std::string tok_(const char* file, int line, const char code[], Platform::Type type = Platform::Type::Native, bool debugwarnings = true, bool preprocess = false) {
-        errout.str("");
-
         const Settings settings = settingsBuilder(settings0).certainty(Certainty::inconclusive).debugwarnings(debugwarnings).platform(type).build();
 
-        Tokenizer tokenizer(&settings, this);
-
         if (preprocess) {
+            Tokenizer tokenizer(settings, *this);
             std::vector<std::string> files(1, "test.cpp");
-            PreprocessorHelper::preprocess(code, files, tokenizer);
+            PreprocessorHelper::preprocess(code, files, tokenizer, *this);
+            std::istringstream istr(code);
+            ASSERT_LOC(tokenizer.list.createTokens(istr, "test.cpp"), file, line); // TODO: this creates the tokens a second time
+            ASSERT_LOC(tokenizer.simplifyTokens1(""), file, line);
+            return tokenizer.tokens()->stringifyList(nullptr);
         }
 
-        std::istringstream istr(code);
-        ASSERT_LOC(tokenizer.tokenize(istr, "test.cpp"), file, line);
+        SimpleTokenizer tokenizer(settings, *this);
+        ASSERT_LOC(tokenizer.tokenize(code), file, line);
 
         return tokenizer.tokens()->stringifyList(nullptr);
     }
@@ -390,7 +392,7 @@ private:
                                 "}";
 
         ASSERT_EQUALS(expected, tok(code));
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
     }
 
     void simplifyUsing14() {
@@ -407,7 +409,7 @@ private:
                             "};";
 
         TODO_ASSERT_THROW(tok(code, Platform::Type::Native, false), InternalError); // TODO: Do not throw AST validation exception
-        //ASSERT_EQUALS("", errout.str());
+        //ASSERT_EQUALS("", errout_str());
     }
 
     void simplifyUsing15() {
@@ -444,7 +446,7 @@ private:
                                 "struct STRFOO s ;";
 
         ASSERT_EQUALS(expected, tok(code));
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
     }
 
     void simplifyUsing17() {
@@ -486,6 +488,7 @@ private:
                             "}\n"
                             "}";
         tok(code); // don't hang
+        ignore_errout(); // we are not interested in the output
     }
 
     void simplifyUsing20() {
@@ -530,6 +533,7 @@ private:
                             "}\n"
                             "}}}}}}}";
         tok(code); // don't hang
+        ignore_errout(); // we do not care about the output
     }
 
     void simplifyUsing21() {
@@ -561,6 +565,7 @@ private:
                                 "} "
                                 "} } } } }";
         ASSERT_EQUALS(expected, tok(code)); // don't hang
+        ignore_errout(); // we do not care about the output
     }
 
     void simplifyUsing23() {
@@ -671,7 +676,7 @@ private:
                             "}\n";
         const char expected[] = "void f ( ) { int * p { new int } ; }";
         ASSERT_EQUALS(expected, tok(code, Platform::Type::Native, /*debugwarnings*/ true));
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
     }
 
     void simplifyUsing29() { // #11981
@@ -679,7 +684,72 @@ private:
                             "void f(T = T()) {}\n";
         const char expected[] = "void f ( int * = ( int * ) 0 ) { }";
         ASSERT_EQUALS(expected, tok(code, Platform::Type::Native, /*debugwarnings*/ true));
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
+    }
+
+    void simplifyUsing30() {
+        {
+            const char code[] = "using std::to_string;\n" // #8454
+                                "void f() {\n"
+                                "    std::string str = to_string(1);\n"
+                                "}\n";
+            const char expected[] = "void f ( ) { std :: string str ; str = std :: to_string ( 1 ) ; }";
+            ASSERT_EQUALS(expected, tok(code, Platform::Type::Native, /*debugwarnings*/ true));
+            ASSERT_EQUALS("", errout_str());
+        }
+        {
+            const char code[] = "using std::cout, std::endl, std::cerr, std::ostringstream;\n"
+                                "cerr << \"abc\";\n";
+            const char expected[] = "std :: cerr << \"abc\" ;";
+            ASSERT_EQUALS(expected, tok(code, Platform::Type::Native, /*debugwarnings*/ true));
+            ASSERT_EQUALS("", errout_str());
+        }
+        {
+            const char code[] = "using std::string_view_literals::operator\"\"sv;\n";
+            const char expected[] = "using std :: string_view_literals :: operator\"\"sv ;";
+            ASSERT_EQUALS(expected, tok(code, Platform::Type::Native, /*debugwarnings*/ true));
+            ASSERT_EQUALS("", errout_str());
+        }
+        {
+            const char code[] = "template <typename T>\n"
+                                "class vector : public ::std::vector<T> {\n"
+                                "public:\n"
+                                "    using ::std::vector<T>::vector;\n"
+                                "    vector() {}\n"
+                                "};\n"
+                                "vector <int> v;\n";
+            const char expected[] = "class vector<int> ; "
+                                    "vector<int> v ; "
+                                    "class vector<int> : public :: std :: vector<int> { "
+                                    "public: "
+                                    "using vector<int> = :: std :: vector<int> :: vector<int> ; "
+                                    "vector<int> ( ) { } "
+                                    "} ;";
+            ASSERT_EQUALS(expected, tok(code, Platform::Type::Native, /*debugwarnings*/ true));
+            ASSERT_EQUALS("", errout_str());
+        }
+        {
+            const char code[] = "using namespace ::std;\n"
+                                "void f(const char* c) {\n"
+                                "    cout << std::string(c) << \"abc\";\n"
+                                "}\n";
+            const char expected[] = "using namespace :: std ; " // TODO: simplify cout?
+                                    "void f ( const char * c ) { "
+                                    "cout << std :: string ( c ) << \"abc\" ; "
+                                    "}";
+            ASSERT_EQUALS(expected, tok(code, Platform::Type::Native, /*debugwarnings*/ true));
+            ASSERT_EQUALS("[test.cpp:3]: (debug) valueFlowConditionExpressions bailout: Skipping function due to incomplete variable cout\n", errout_str());
+        }
+        {
+            const char code[] = "class T : private std::vector<std::pair<std::string, const int*>> {\n" // #12521
+                                "    using std::vector<std::pair<std::string, const int*>>::empty;\n"
+                                "};\n";
+            const char expected[] = "class T : private std :: vector < std :: pair < std :: string , const int * > > { "
+                                    "using empty = std :: vector < std :: pair < std :: string , const int * > > :: empty ; "
+                                    "} ;";
+            ASSERT_EQUALS(expected, tok(code, Platform::Type::Native, /*debugwarnings*/ true));
+            ASSERT_EQUALS("", errout_str());
+        }
     }
 
     void simplifyUsing8970() {
@@ -784,6 +854,9 @@ private:
                            "}";
 
         ASSERT_EQUALS(exp, tok(code));
+        ASSERT_EQUALS("[test.cpp:7]: (debug) valueFlowConditionExpressions bailout: Skipping function due to incomplete variable NS1\n"
+                      "[test.cpp:11]: (debug) valueFlowConditionExpressions bailout: Skipping function due to incomplete variable NS2\n",
+                      errout_str());
     }
 
     void simplifyUsing9381() {
@@ -953,7 +1026,7 @@ private:
                                 "} "
                                 "struct external :: ns1 :: B<1> { } ;";
             ASSERT_EQUALS(exp, tok(code));
-            ASSERT_EQUALS("", errout.str());
+            ASSERT_EQUALS("", errout_str());
         }
         {
             // no using "namespace external::ns1;"
@@ -986,7 +1059,7 @@ private:
                                 "} "
                                 "struct external :: ns1 :: B<1> { } ;";
             ASSERT_EQUALS(exp, tok(code));
-            ASSERT_EQUALS("", errout.str());
+            ASSERT_EQUALS("", errout_str());
         }
         {
             // using "namespace external::ns1;" without redundant qualification
@@ -1021,7 +1094,7 @@ private:
                                 "} "
                                 "struct external :: ns1 :: B<1> { } ;";
             ASSERT_EQUALS(exp, tok(code));
-            ASSERT_EQUALS("", errout.str());
+            ASSERT_EQUALS("", errout_str());
         }
         {
             // using "namespace external::ns1;" without redundant qualification on declaration and definition
@@ -1056,7 +1129,7 @@ private:
                                 "} "
                                 "struct external :: ns1 :: B<1> { } ;";
             ASSERT_EQUALS(exp, tok(code));
-            ASSERT_EQUALS("", errout.str());
+            ASSERT_EQUALS("", errout_str());
         }
         {
             const char code[] = "namespace external {\n"
@@ -1086,7 +1159,7 @@ private:
                                 "} "
                                 "struct external :: B<1> { } ;";
             ASSERT_EQUALS(exp, tok(code));
-            ASSERT_EQUALS("", errout.str());
+            ASSERT_EQUALS("", errout_str());
         }
         {
             const char code[] = "template <int size> struct B { };\n"
@@ -1114,7 +1187,7 @@ private:
                                 "} "
                                 "struct B<1> { } ;";
             ASSERT_EQUALS(exp, tok(code));
-            ASSERT_EQUALS("", errout.str());
+            ASSERT_EQUALS("", errout_str());
         }
     }
 
@@ -1140,7 +1213,7 @@ private:
                                 "} ; "
                                 "void A :: f ( const std :: vector < char > & ) const { }";
             ASSERT_EQUALS(exp, tok(code));
-            ASSERT_EQUALS("", errout.str());
+            ASSERT_EQUALS("", errout_str());
         }
         {
             const char code[] = "namespace NS1 {\n"
@@ -1199,7 +1272,7 @@ private:
                                 "c . f ( v ) ; "
                                 "}";
             ASSERT_EQUALS(exp, tok(code));
-            ASSERT_EQUALS("", errout.str());
+            ASSERT_EQUALS("", errout_str());
         }
         {
             const char code[] = "foo::ResultCodes_e\n"
@@ -1227,6 +1300,7 @@ private:
                                 "   return ret;\n"
                                 "}";
             tok(code); // don't crash
+            ignore_errout(); // we do not care about the output
         }
     }
 
@@ -1259,7 +1333,7 @@ private:
                            "void B :: f ( const std :: vector < unsigned char > & ) const { } "
                            "}";
         ASSERT_EQUALS(exp, tok(code));
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
     }
 
     void simplifyUsing10172() {
@@ -1288,7 +1362,7 @@ private:
                                "void B :: f ( std :: function < void ( ) > ) { } "
                                "}";
             ASSERT_EQUALS(exp, tok(code));
-            ASSERT_EQUALS("", errout.str());
+            ASSERT_EQUALS("", errout_str());
         }
         {
             const char code[] = "namespace ns {\n"
@@ -1323,7 +1397,7 @@ private:
                                "} "
                                "}";
             ASSERT_EQUALS(exp, tok(code));
-            ASSERT_EQUALS("", errout.str());
+            ASSERT_EQUALS("", errout_str());
         }
     }
 
@@ -1349,7 +1423,7 @@ private:
                                 "Pr < st > p ; "
                                 "}";
             ASSERT_EQUALS(exp, tok(code));
-            ASSERT_EQUALS("", errout.str());
+            ASSERT_EQUALS("", errout_str());
         }
         {
             const char code[] = "namespace defsa {\n"
@@ -1372,6 +1446,7 @@ private:
                                 "} "
                                 "}";
             ASSERT_EQUALS(exp, tok(code));
+            ignore_errout(); // we do not care about the output
         }
     }
 
@@ -1390,7 +1465,7 @@ private:
                             "STAMP(B, A);\n"
                             "STAMP(C, B);\n";
         tok(code, Platform::Type::Native, /*debugwarnings*/ true, /*preprocess*/ true);
-        ASSERT(startsWith(errout.str(), "[test.cpp:6]: (debug) Failed to parse 'using C = S < S < S < int"));
+        ASSERT(startsWith(errout_str(), "[test.cpp:6]: (debug) Failed to parse 'using C = S < S < S < int"));
     }
 
     void scopeInfo1() {
@@ -1401,7 +1476,7 @@ private:
                             "namespace spdlog { class logger; }\n"
                             "using LoggerPtr = std::shared_ptr<spdlog::logger>;";
         tok(code);
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
     }
 
     void scopeInfo2() {
@@ -1413,7 +1488,7 @@ private:
                             "static void getInitialProgramState(const A::Map& vars = A::Map {})\n"
                             "{}\n";
         tok(code);
-        ASSERT_EQUALS("", errout.str());
+        ASSERT_EQUALS("", errout_str());
     }
 };
 
