@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2024 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,12 +18,13 @@
 
 #include "settings.h"
 #include "fixture.h"
+#include "helpers.h"
 #include "platform.h"
 #include "standards.h"
 #include "token.h"
 #include "tokenlist.h"
 
-#include <sstream> // IWYU pragma: keep
+#include <sstream>
 #include <string>
 
 class TestTokenList : public TestFixture {
@@ -50,23 +51,17 @@ private:
 
     void testaddtoken2() const {
         const std::string code = "0xF0000000";
-        Settings settings1;
+        /*const*/ Settings settings1;
         settings1.platform.int_bit = 32;
         TokenList tokenlist(&settings1);
         tokenlist.addtoken(code, 1, 1, false);
         ASSERT_EQUALS("0xF0000000", tokenlist.front()->str());
     }
 
-    void inc() {
+    void inc() const {
         const char code[] = "a++1;1++b;";
 
-        errout.str("");
-
-        // tokenize..
-        TokenList tokenlist(&settings);
-        std::istringstream istr(code);
-        tokenlist.createTokens(istr, "a.cpp");
-
+        const SimpleTokenList tokenlist(code);
         ASSERT(Token::simpleMatch(tokenlist.front(), "a + + 1 ; 1 + + b ;"));
     }
 
@@ -75,9 +70,7 @@ private:
         const char code[] = "for a int delete true";
 
         {
-            TokenList tokenlist(&settings);
-            std::istringstream istr(code);
-            tokenlist.createTokens(istr, "a.c");
+            const SimpleTokenList tokenlist(code, Standards::Language::C);
 
             ASSERT_EQUALS(true, tokenlist.front()->isKeyword());
             ASSERT_EQUALS(true, tokenlist.front()->isControlFlowKeyword());
@@ -93,9 +86,7 @@ private:
             ASSERT_EQUALS(false, tokenlist.front()->tokAt(4)->isControlFlowKeyword());
         }
         {
-            TokenList tokenlist(&settings);
-            std::istringstream istr(code);
-            tokenlist.createTokens(istr, "a.cpp");
+            const SimpleTokenList tokenlist(code);
 
             ASSERT_EQUALS(true, tokenlist.front()->isKeyword());
             ASSERT_EQUALS(true, tokenlist.front()->isControlFlowKeyword());
@@ -113,17 +104,13 @@ private:
 
         {
             const char code2[] = "_Generic"; // C11 keyword
-            TokenList tokenlist(nullptr); // no settings use latest standard
-            std::istringstream istr(code2);
-            tokenlist.createTokens(istr, "a.cpp");
+            const SimpleTokenList tokenlist(code2); // default settings use latest standard
             ASSERT_EQUALS(false, tokenlist.front()->isKeyword());
         }
 
         {
             const char code2[] = "_Generic"; // C11 keyword
-            TokenList tokenlist(nullptr); // no settings use latest standard
-            std::istringstream istr(code2);
-            tokenlist.createTokens(istr, "a.c");
+            const SimpleTokenList tokenlist(code2, Standards::Language::C); // default settings use latest standard
             ASSERT_EQUALS(true, tokenlist.front()->isKeyword());
         }
 
@@ -132,23 +119,19 @@ private:
             const Settings s = settingsBuilder().c(Standards::C89).build();
             TokenList tokenlist(&s);
             std::istringstream istr(code2);
-            tokenlist.createTokens(istr, "a.c");
+            ASSERT(tokenlist.createTokens(istr, "a.c"));
             ASSERT_EQUALS(false, tokenlist.front()->isKeyword());
         }
 
         {
             const char code2[] = "co_return"; // C++20 keyword
-            TokenList tokenlist(nullptr); // no settings use latest standard
-            std::istringstream istr(code2);
-            tokenlist.createTokens(istr, "a.cpp");
+            const SimpleTokenList tokenlist(code2); // default settings use latest standard
             ASSERT_EQUALS(true, tokenlist.front()->isKeyword());
         }
 
         {
             const char code2[] = "co_return"; // C++20 keyword
-            TokenList tokenlist(nullptr); // no settings use latest standard
-            std::istringstream istr(code2);
-            tokenlist.createTokens(istr, "a.c");
+            const SimpleTokenList tokenlist(code2, Standards::Language::C); // default settings use latest standard
             ASSERT_EQUALS(false, tokenlist.front()->isKeyword());
         }
 
@@ -157,7 +140,7 @@ private:
             const Settings s = settingsBuilder().cpp(Standards::CPP03).build();
             TokenList tokenlist(&s);
             std::istringstream istr(code2);
-            tokenlist.createTokens(istr, "a.cpp");
+            ASSERT(tokenlist.createTokens(istr, "a.cpp"));
             ASSERT_EQUALS(false, tokenlist.front()->isKeyword());
         }
     }
