@@ -179,7 +179,7 @@ class MatchCompiler:
         elif tok == '%str%':
             return '(tok->tokType() == Token::eString)'
         elif tok == '%type%':
-            return '(tok->isName() && tok->varId() == 0U && (tok->str() != MatchCompiler::makeConstString("delete") || !tok->isKeyword()))'
+            return '(tok->isName() && tok->varId() == 0U)'
         elif tok == '%name%':
             return 'tok->isName()'
         elif tok == '%var%':
@@ -760,7 +760,7 @@ def main():
 
     # Check if we are invoked from the right place
     if not os.path.exists(lib_dir):
-        print('Directory "' + lib_dir + '"not found.')
+        print('Directory "' + lib_dir + '" not found.')
         sys.exit(-1)
 
     # Create build directory if needed
